@@ -3,7 +3,7 @@
 # include "elementary_config.h"
 #endif
 #include <Elementary.h>
-#ifndef ELM_LIB_QUICKLAUNCH
+
 
 // XXX: show all type of cursors in the elementary_test. this needs to be the first test
 
@@ -18,7 +18,7 @@ typedef struct _Testitem
 static Elm_Gengrid_Item_Class gic;
 
 char *
-grd_lbl_get(void *data, Evas_Object *obj __UNUSED__, const char *part __UNUSED__)
+grd_lbl_get(void *data, Evas_Object *obj EINA_UNUSED, const char *part EINA_UNUSED)
 {
    const Testitem *ti = data;
    char buf[256];
@@ -45,7 +45,7 @@ grd_content_get(void *data, Evas_Object *obj, const char *part)
 static Elm_Genlist_Item_Class itct;
 
 static void
-glt_exp(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info)
+glt_exp(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Elm_Object_Item *glit = event_info;
    Evas_Object *gl = elm_object_item_widget_get(glit);
@@ -67,28 +67,28 @@ glt_exp(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info)
 }
 
 static void
-glt_con(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info)
+glt_con(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Elm_Object_Item *glit = event_info;
    elm_genlist_item_subitems_clear(glit);
 }
 
 static void
-glt_exp_req(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info)
+glt_exp_req(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Elm_Object_Item *glit = event_info;
    elm_genlist_item_expanded_set(glit, EINA_TRUE);
 }
 
 static void
-glt_con_req(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info)
+glt_con_req(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Elm_Object_Item *glit = event_info;
    elm_genlist_item_expanded_set(glit, EINA_FALSE);
 }
 
 char *
-glt_text_get(void *data, Evas_Object *obj __UNUSED__, const char *part __UNUSED__)
+glt_text_get(void *data, Evas_Object *obj EINA_UNUSED, const char *part EINA_UNUSED)
 {
    char buf[256];
    snprintf(buf, sizeof(buf), "Item mode %i", (int)(uintptr_t)data);
@@ -96,7 +96,7 @@ glt_text_get(void *data, Evas_Object *obj __UNUSED__, const char *part __UNUSED_
 }
 
 void
-test_cursor(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+test_cursor(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win, *bg, *bx, *bt, *list, *entry, *ck;
    Elm_Object_Item *lit;
@@ -106,8 +106,8 @@ test_cursor(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info
    elm_win_autodel_set(win, EINA_TRUE);
 
    bg = elm_bg_add(win);
-   elm_win_resize_object_add(win, bg);
    evas_object_size_hint_weight_set(bg, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   elm_win_resize_object_add(win, bg);
    evas_object_show(bg);
    elm_object_cursor_set(bg, ELM_CURSOR_CIRCLE);
 
@@ -163,7 +163,7 @@ test_cursor(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info
 }
 
 void
-test_cursor2(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+test_cursor2(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win, *bx, *o, *grid, *gl;
    Elm_Object_Item *glit1, *glit2, *glit3;
@@ -194,7 +194,7 @@ test_cursor2(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_inf
    evas_object_show(bx);
 
    o = elm_toolbar_add(win);
-   elm_toolbar_homogeneous_set(o, 0);
+   elm_toolbar_homogeneous_set(o, EINA_FALSE);
    evas_object_size_hint_weight_set(o, 0.0, 0.0);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.0);
    tb_it = elm_toolbar_item_append(o, NULL, "Bogosity", NULL, NULL);
@@ -281,7 +281,7 @@ test_cursor2(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_inf
 }
 
 void
-test_cursor3(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+test_cursor3(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win, *bx, *o;
    Elm_Object_Item *lit;
@@ -300,7 +300,7 @@ test_cursor3(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_inf
 
    o = elm_button_add(win);
    elm_object_cursor_set(o, ELM_CURSOR_HAND1);
-   elm_object_cursor_theme_search_enabled_set(o, EINA_FALSE);
+   elm_object_cursor_theme_search_enabled_set(o, EINA_TRUE);
    elm_object_text_set(o, "hand1");
    elm_box_pack_end(bx, o);
    evas_object_show(o);
@@ -313,21 +313,21 @@ test_cursor3(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_inf
 
    o = elm_button_add(win);
    elm_object_cursor_set(o, ELM_CURSOR_HAND2);
-   elm_object_cursor_theme_search_enabled_set(o, EINA_FALSE);
+   elm_object_cursor_theme_search_enabled_set(o, EINA_TRUE);
    elm_object_text_set(o, "hand2");
    elm_box_pack_end(bx, o);
    evas_object_show(o);
 
    o = elm_button_add(win);
    elm_object_cursor_set(o, "hand3");
-   elm_object_cursor_theme_search_enabled_set(o, EINA_FALSE);
+   elm_object_cursor_theme_search_enabled_set(o, EINA_TRUE);
    elm_object_text_set(o, "hand3");
    elm_box_pack_end(bx, o);
    evas_object_show(o);
 
    o = elm_button_add(win);
    elm_object_cursor_set(o, "hand3");
-   elm_object_cursor_theme_search_enabled_set(o, EINA_FALSE);
+   elm_object_cursor_theme_search_enabled_set(o, EINA_TRUE);
    elm_object_cursor_style_set(o, "transparent");
    elm_object_text_set(o, "hand3 transparent");
    elm_box_pack_end(bx, o);
@@ -335,7 +335,7 @@ test_cursor3(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_inf
 
    o = elm_button_add(win);
    elm_object_cursor_set(o, "hand3");
-   elm_object_cursor_theme_search_enabled_set(o, EINA_FALSE);
+   elm_object_cursor_theme_search_enabled_set(o, EINA_TRUE);
    elm_object_cursor_unset(o);
    elm_object_text_set(o, "unset");
    elm_box_pack_end(bx, o);
@@ -386,7 +386,7 @@ test_cursor3(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_inf
 }
 
 void
-test_cursor4(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+test_cursor4(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win, *bx, *ly, *bt;
    char buf[PATH_MAX];
@@ -447,4 +447,3 @@ test_cursor4(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_inf
    evas_object_show(win);
 }
 
-#endif
