@@ -2,7 +2,7 @@
 # include "elementary_config.h"
 #endif
 #include <Elementary.h>
-#ifndef ELM_LIB_QUICKLAUNCH
+
 
 #define TAP_NAME "tap"
 #define DOUBLE_TAP_NAME "double_tap"
@@ -60,6 +60,7 @@ struct _infra_data
    icon_properties *icons;
    Ecore_Timer *colortimer;
    char buf[1024];
+   int long_tap_count;
 };
 typedef struct _infra_data infra_data;
 
@@ -89,7 +90,7 @@ _infra_data_alloc(void)
 }
 
 static void
-my_win_del(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+my_win_del(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {  /* called when my_win_main is requested to be deleted */
    _infra_data_free(data);
 }
@@ -206,10 +207,12 @@ static Evas_Event_Flags
 n_long_tap_start(void *data , void *event_info)
 {
    Elm_Gesture_Taps_Info *p = (Elm_Gesture_Taps_Info *) event_info;
+   infra_data *infra = data;
 
    printf("N long tap started <%p> x,y=<%d,%d> count=<%d>\n",
          event_info, p->x, p->y, p->n);
    _color_and_icon_set(data, LONG_TAP_NAME, p->n, MAX_LONG_TAP, START_COLOR);
+   infra->long_tap_count = 0;
    return EVAS_EVENT_FLAG_ON_HOLD;
 }
 
@@ -217,10 +220,16 @@ static Evas_Event_Flags
 n_long_tap_move(void *data , void *event_info)
 {
    Elm_Gesture_Taps_Info *p = (Elm_Gesture_Taps_Info *) event_info;
+   infra_data *infra = data;
+
+   infra->long_tap_count++;
    _color_and_icon_set(data, LONG_TAP_NAME, p->n, MAX_LONG_TAP, MOVE_COLOR);
 
    printf("N long tap moved <%p> x,y=<%d,%d> count=<%d>\n",
          event_info, p->x, p->y, p->n);
+   if (infra->long_tap_count == 1)
+     printf("This is a first long tap.\n");
+
    return EVAS_EVENT_FLAG_ON_HOLD;
 }
 
@@ -255,6 +264,17 @@ dbl_click_start(void *data , void *event_info)
    return EVAS_EVENT_FLAG_ON_HOLD;
 }
 
+static Evas_Event_Flags
+dbl_click_move(void *data , void *event_info)
+{
+   Elm_Gesture_Taps_Info *p = (Elm_Gesture_Taps_Info *) event_info;
+   _color_and_icon_set(data, DOUBLE_TAP_NAME, p->n, MAX_DOUBLE_TAP, MOVE_COLOR);
+
+   printf("Double click move <%p> x,y=<%d,%d> count=<%d>\n",
+         event_info, p->x, p->y, p->n);
+   return EVAS_EVENT_FLAG_ON_HOLD;
+}
+
 static Evas_Event_Flags
 dbl_click_end(void *data , void *event_info)
 {
@@ -287,6 +307,17 @@ triple_click_start(void *data , void *event_info)
    return EVAS_EVENT_FLAG_ON_HOLD;
 }
 
+static Evas_Event_Flags
+triple_click_move(void *data , void *event_info)
+{
+   Elm_Gesture_Taps_Info *p = (Elm_Gesture_Taps_Info *) event_info;
+
+   _color_and_icon_set(data, TRIPLE_TAP_NAME, p->n, MAX_TRIPLE_TAP, MOVE_COLOR);
+   printf("Triple click move <%p> x,y=<%d,%d> count=<%d>\n",
+         event_info, p->x, p->y, p->n);
+   return EVAS_EVENT_FLAG_ON_HOLD;
+}
+
 static Evas_Event_Flags
 triple_click_end(void *data , void *event_info)
 {
@@ -447,7 +478,7 @@ zoom_end(void *data , void *event_info)
 }
 
 static Evas_Event_Flags
-zoom_abort(void *data , void *event_info __UNUSED__)
+zoom_abort(void *data , void *event_info EINA_UNUSED)
 {
    printf("zoom abort\n");
    _color_and_icon_set(data, ZOOM_NAME, MAX_ZOOM, MAX_ZOOM, ABORT_COLOR);
@@ -482,7 +513,7 @@ rotate_end(void *data , void *event_info)
 }
 
 static Evas_Event_Flags
-rotate_abort(void *data , void *event_info __UNUSED__)
+rotate_abort(void *data , void *event_info EINA_UNUSED)
 {
    _color_and_icon_set(data, ROTATE_NAME, MAX_ROTATE, MAX_ROTATE, ABORT_COLOR);
    printf("rotate abort\n");
@@ -520,8 +551,8 @@ Evas_Object *create_gesture_box(Evas_Object *win, icon_properties *icons,
 }
 
 void
-test_gesture_layer2(void *data __UNUSED__, Evas_Object *obj __UNUSED__,
-      void *event_info __UNUSED__)
+test_gesture_layer2(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED,
+      void *event_info EINA_UNUSED)
 {
    Evas_Object *win, *tb, *lb, *bx;
    Evas_Object *r; /* Gesture layer transparent object */
@@ -537,9 +568,9 @@ test_gesture_layer2(void *data __UNUSED__, Evas_Object *obj __UNUSED__,
    bx = elm_box_add(win);
    tb = elm_table_add(win);
    elm_box_pack_end(bx, tb);
-   elm_win_resize_object_add(win, bx);
    evas_object_size_hint_weight_set(bx, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
    evas_object_size_hint_align_set(tb, 0.5, 0.5);
+   elm_win_resize_object_add(win, bx);
    evas_object_show(tb);
    evas_object_show(bx);
 
@@ -681,6 +712,8 @@ test_gesture_layer2(void *data __UNUSED__, Evas_Object *obj __UNUSED__,
 #if 1
    elm_gesture_layer_cb_set(g, ELM_GESTURE_N_TRIPLE_TAPS,
          ELM_GESTURE_STATE_START, triple_click_start, infra);
+   elm_gesture_layer_cb_set(g, ELM_GESTURE_N_TRIPLE_TAPS,
+         ELM_GESTURE_STATE_MOVE, triple_click_move, infra);
    elm_gesture_layer_cb_set(g, ELM_GESTURE_N_TRIPLE_TAPS,
          ELM_GESTURE_STATE_END, triple_click_end, infra);
    elm_gesture_layer_cb_set(g, ELM_GESTURE_N_TRIPLE_TAPS,
@@ -690,6 +723,8 @@ test_gesture_layer2(void *data __UNUSED__, Evas_Object *obj __UNUSED__,
 #if 1
    elm_gesture_layer_cb_set(g, ELM_GESTURE_N_DOUBLE_TAPS,
          ELM_GESTURE_STATE_START, dbl_click_start, infra);
+   elm_gesture_layer_cb_set(g, ELM_GESTURE_N_DOUBLE_TAPS,
+         ELM_GESTURE_STATE_MOVE, dbl_click_move, infra);
    elm_gesture_layer_cb_set(g, ELM_GESTURE_N_DOUBLE_TAPS,
          ELM_GESTURE_STATE_END, dbl_click_end, infra);
    elm_gesture_layer_cb_set(g, ELM_GESTURE_N_DOUBLE_TAPS,
@@ -777,4 +812,3 @@ test_gesture_layer2(void *data __UNUSED__, Evas_Object *obj __UNUSED__,
 
    evas_object_show(win);
 }
-#endif
