@@ -2,7 +2,7 @@
 # include "elementary_config.h"
 #endif
 #include <Elementary.h>
-#ifndef ELM_LIB_QUICKLAUNCH
+
 
 #include <Elementary.h>
 #ifndef M_PI
@@ -482,51 +482,74 @@ _quit_idler(void *data)
 
 static void
 _on_done(void *data,
-         Evas_Object *obj __UNUSED__,
-         void *event_info __UNUSED__)
+         Evas_Object *obj EINA_UNUSED,
+         void *event_info EINA_UNUSED)
 {
    ecore_idler_add(_quit_idler, data);
 }
 
 static void
-_del(void *data __UNUSED__, Evas *evas __UNUSED__, Evas_Object *obj, void *event_info __UNUSED__)
+_on_direct(void *data,
+           Evas_Object *obj EINA_UNUSED,
+           void *event_info EINA_UNUSED)
+{
+   elm_glview_mode_set(data, 0
+                       | ELM_GLVIEW_ALPHA
+                       | ELM_GLVIEW_DEPTH
+                       | ELM_GLVIEW_DIRECT
+                      );
+}
+
+static void
+_on_indirect(void *data,
+           Evas_Object *obj EINA_UNUSED,
+           void *event_info EINA_UNUSED)
+{
+   elm_glview_mode_set(data, 0
+                       | ELM_GLVIEW_ALPHA
+                       | ELM_GLVIEW_DEPTH
+                      );
+}
+
+static void
+_del(void *data EINA_UNUSED, Evas *evas EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    Ecore_Animator *ani = evas_object_data_get(obj, "ani");
    ecore_animator_del(ani);
 }
 
 static void
-_key_down(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj, void *event_info)
+_key_down(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj, void *event_info)
 {
    Evas_Event_Key_Down *ev;
    ev = (Evas_Event_Key_Down *)event_info;
    GLData *gld = evas_object_data_get(obj, "gld");
 
-   if (strcmp(ev->keyname, "Left") == 0)
+   if (strcmp(ev->key, "Left") == 0)
      {
         gld->view_roty += 5.0;
         return;
      }
 
-   if (strcmp(ev->keyname, "Right") == 0)
+   if (strcmp(ev->key, "Right") == 0)
      {
         gld->view_roty -= 5.0;
         return;
      }
 
-   if (strcmp(ev->keyname, "Up") == 0)
+   if (strcmp(ev->key, "Up") == 0)
      {
         gld->view_rotx += 5.0;
         return;
      }
 
-   if (strcmp(ev->keyname, "Down") == 0)
+   if (strcmp(ev->key, "Down") == 0)
      {
         gld->view_rotx -= 5.0;
         return;
      }
-   if ((strcmp(ev->keyname, "Escape") == 0) ||
-       (strcmp(ev->keyname, "Return") == 0))
+   if ((strcmp(ev->key, "Escape") == 0) ||
+       (strcmp(ev->key, "Return") == 0))
      {
         //_on_done(data, obj, event_info);
         return;
@@ -534,14 +557,14 @@ _key_down(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj, void *eve
 }
 
 static void
-_mouse_down(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj, void *event_info __UNUSED__)
+_mouse_down(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    GLData *gld = evas_object_data_get(obj, "gld");
    gld->mouse_down = 1;
 }
 
 static void
-_mouse_move(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj, void *event_info __UNUSED__)
+_mouse_move(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    Evas_Event_Mouse_Move *ev;
    ev = (Evas_Event_Mouse_Move *)event_info;
@@ -559,16 +582,16 @@ _mouse_move(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj, void *e
 }
 
 static void
-_mouse_up(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj, void *event_info __UNUSED__)
+_mouse_up(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    GLData *gld = evas_object_data_get(obj, "gld");
    gld->mouse_down = 0;
 }
 
 void
-test_glview(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+test_glview(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
-   Evas_Object *win, *bx, *bt, *gl;
+   Evas_Object *win, *bx0, *bx, *bt, *gl;
    Ecore_Animator *ani;
    GLData *gld = NULL;
 
@@ -577,24 +600,48 @@ test_glview(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info
    gldata_init(gld);
 
    // new window - do the usual and give it a name, title and delete handler
-   // Set the engine to opengl_x11
-   elm_config_preferred_engine_set("opengl_x11");
    win = elm_win_util_standard_add("glview", "GLView");
-   // Set preferred engine back to default from config
-   elm_config_preferred_engine_set(NULL);
 
    elm_win_autodel_set(win, EINA_TRUE);
 
+   bx0 = elm_box_add(win);
+   elm_box_horizontal_set(bx0, EINA_TRUE);
+   evas_object_size_hint_weight_set(bx0, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   elm_win_resize_object_add(win, bx0);
+   evas_object_show(bx0);
+
+   /* add an ok button */
+   bt = elm_button_add(win);
+   elm_object_text_set(bt, "OK");
+   evas_object_size_hint_align_set(bt, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   evas_object_size_hint_weight_set(bt, 0.0, EVAS_HINT_EXPAND);
+   elm_box_pack_end(bx0, bt);
+   evas_object_show(bt);
+   evas_object_smart_callback_add(bt, "clicked", _on_done, win);
+
    bx = elm_box_add(win);
+   evas_object_size_hint_align_set(bx, EVAS_HINT_FILL, EVAS_HINT_FILL);
    evas_object_size_hint_weight_set(bx, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
-   elm_win_resize_object_add(win, bx);
+   elm_box_pack_end(bx0, bx);
    evas_object_show(bx);
 
+   /* add an ok button */
+   bt = elm_button_add(win);
+   elm_object_text_set(bt, "OK");
+   evas_object_size_hint_align_set(bt, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   evas_object_size_hint_weight_set(bt, EVAS_HINT_EXPAND, 0.0);
+   elm_box_pack_end(bx, bt);
+   evas_object_show(bt);
+   evas_object_smart_callback_add(bt, "clicked", _on_done, win);
+
    // Add a GLView
    gl = elm_glview_add(win);
    evas_object_size_hint_align_set(gl, EVAS_HINT_FILL, EVAS_HINT_FILL);
    evas_object_size_hint_weight_set(gl, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
-   elm_glview_mode_set(gl, ELM_GLVIEW_ALPHA|ELM_GLVIEW_DEPTH);
+   elm_glview_mode_set(gl, 0
+                       | ELM_GLVIEW_ALPHA
+                       | ELM_GLVIEW_DEPTH
+                      );
    elm_glview_resize_policy_set(gl, ELM_GLVIEW_RESIZE_POLICY_RECREATE);
    elm_glview_render_policy_set(gl, ELM_GLVIEW_RENDER_POLICY_ALWAYS);
    elm_glview_init_func_set(gl, _init_gl);
@@ -620,14 +667,22 @@ test_glview(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info
 
    /* add an ok button */
    bt = elm_button_add(win);
-   elm_object_text_set(bt, "OK");
+   elm_object_text_set(bt, "Direct");
    evas_object_size_hint_align_set(bt, EVAS_HINT_FILL, EVAS_HINT_FILL);
    evas_object_size_hint_weight_set(bt, EVAS_HINT_EXPAND, 0.0);
    elm_box_pack_end(bx, bt);
    evas_object_show(bt);
-   evas_object_smart_callback_add(bt, "clicked", _on_done, win);
+   evas_object_smart_callback_add(bt, "clicked", _on_direct, gl);
+
+   /* add an ok button */
+   bt = elm_button_add(win);
+   elm_object_text_set(bt, "I");
+   evas_object_size_hint_align_set(bt, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   evas_object_size_hint_weight_set(bt, 0.0, EVAS_HINT_EXPAND);
+   elm_box_pack_end(bx0, bt);
+   evas_object_show(bt);
+   evas_object_smart_callback_add(bt, "clicked", _on_indirect, gl);
 
    evas_object_resize(win, 320, 480);
    evas_object_show(win);
 }
-#endif
