@@ -1,82 +1,81 @@
-#include <Elementary.h>
 #ifdef HAVE_CONFIG_H
 # include "elementary_config.h"
 #endif
-#ifndef ELM_LIB_QUICKLAUNCH
+#include <Elementary.h>
 
-static double size = 0.0;
 
 static void
-_press(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+_press(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
-    printf("press\n");
+   printf("press\n");
 }
 
 static void
-_unpress(void *data __UNUSED__, Evas_Object *obj, void *event_info __UNUSED__)
+_unpress(void *data EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
-    printf("unpress, size : %f\n", elm_panes_content_left_size_get(obj));
+   printf("unpress, size : %f\n", elm_panes_content_left_size_get(obj));
 }
 
 static void
-_clicked(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+_clicked(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
-    printf("clicked\n");
+   printf("clicked\n");
 }
 
-
 static void
-_clicked_double(void *data __UNUSED__, Evas_Object *obj, void *event_info __UNUSED__)
+_clicked_double(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
-    printf("clicked double\n");
-    if(elm_panes_content_left_size_get(obj) > 0)
-    {
-        size = elm_panes_content_left_size_get(obj);
+   double *size = data;
+   double tmp_size = 0.0;
+
+   tmp_size = elm_panes_content_left_size_get(obj);
+   printf("clicked double\n");
+   if (tmp_size > 0)
+     {
         elm_panes_content_left_size_set(obj, 0.0);
-    }
-    else
-        elm_panes_content_left_size_set(obj, size);
+        *size = tmp_size;
+     }
+   else
+     elm_panes_content_left_size_set(obj, *size);
 }
 
-
 void
-test_panes(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+test_panes(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win, *bg, *panes, *panes_h, *bt;
+   static double vbar_size = 0.0;
+   static double hbar_size = 0.0;
 
    win = elm_win_add(NULL, "panes", ELM_WIN_BASIC);
    elm_win_title_set(win, "Panes");
-   elm_win_autodel_set(win, 1);
+   elm_win_autodel_set(win, EINA_TRUE);
 
    bg = elm_bg_add(win);
-   elm_win_resize_object_add(win, bg);
    evas_object_size_hint_weight_set(bg, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   elm_win_resize_object_add(win, bg);
    elm_win_focus_highlight_enabled_set(win, EINA_TRUE);
    evas_object_show(bg);
 
    panes = elm_panes_add(win);
-   elm_win_resize_object_add(win, panes);
    evas_object_size_hint_weight_set(panes, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
-   evas_object_size_hint_align_set(panes, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   elm_win_resize_object_add(win, panes);
    evas_object_show(panes);
 
    evas_object_smart_callback_add(panes, "clicked", _clicked, panes);
-   evas_object_smart_callback_add(panes, "clicked,double", _clicked_double, panes);
+   evas_object_smart_callback_add(panes, "clicked,double", _clicked_double, &vbar_size);
 
    evas_object_smart_callback_add(panes, "press", _press, panes);
    evas_object_smart_callback_add(panes, "unpress", _unpress, panes);
 
-
-   //
+   // add left button
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Left");
-   evas_object_size_hint_weight_set(bt, 1.0, 1.0);
-   evas_object_size_hint_align_set(bt, -1.0, -1.0);
+   elm_object_text_set(bt, "Left");
+   evas_object_size_hint_weight_set(bt, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   evas_object_size_hint_align_set(bt, EVAS_HINT_FILL, EVAS_HINT_FILL);
    evas_object_show(bt);
-   elm_panes_content_left_set(panes, bt);
-   //
+   elm_object_part_content_set(panes, "left", bt);
 
-   //
+   // add panes
    panes_h = elm_panes_add(win);
    elm_panes_horizontal_set(panes_h, EINA_TRUE);
    evas_object_size_hint_weight_set(panes_h, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
@@ -84,35 +83,29 @@ test_panes(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info
    evas_object_show(panes_h);
 
    evas_object_smart_callback_add(panes_h, "clicked", _clicked, panes_h);
-   evas_object_smart_callback_add(panes_h, "clicked,double", _clicked_double, panes_h);
+   evas_object_smart_callback_add(panes_h, "clicked,double", _clicked_double, &hbar_size);
 
    evas_object_smart_callback_add(panes_h, "press", _press, panes_h);
    evas_object_smart_callback_add(panes_h, "unpress", _unpress, panes_h);
-   elm_panes_content_right_set(panes, panes_h);
-   //
+   elm_object_part_content_set(panes, "right", panes_h);
 
-   //
+   // add up button
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Up");
+   elm_object_text_set(bt, "Up");
    evas_object_size_hint_weight_set(bt, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
    evas_object_size_hint_align_set(bt, EVAS_HINT_FILL, EVAS_HINT_FILL);
    evas_object_show(bt);
-   elm_panes_content_left_set(panes_h, bt);
-   //
+   elm_object_part_content_set(panes_h, "top", bt);
 
-   //
+   // add down button
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Down");
+   elm_object_text_set(bt, "Down");
    evas_object_size_hint_weight_set(bt, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
    evas_object_size_hint_align_set(bt, EVAS_HINT_FILL, EVAS_HINT_FILL);
    evas_object_show(bt);
-   elm_panes_content_right_set(panes_h, bt);
-   //
-
+   elm_object_part_content_set(panes_h, "bottom", bt);
 
    evas_object_resize(win, 320, 400);
    evas_object_show(win);
 }
 
-
-#endif
