@@ -2,7 +2,7 @@
 # include "elementary_config.h"
 #endif
 #include <Elementary.h>
-#ifndef ELM_LIB_QUICKLAUNCH
+
 typedef struct _Testitem
 {
    Elm_Object_Item *item;
@@ -10,9 +10,10 @@ typedef struct _Testitem
 } Testitem;
 
 static int rotate_with_resize = 0;
+static Eina_Bool fullscreen = EINA_FALSE;
 
 static void
-my_bt_38_alpha_on(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+my_bt_38_alpha_on(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win = data;
    Evas_Object *bg = evas_object_data_get(win, "bg");
@@ -21,7 +22,7 @@ my_bt_38_alpha_on(void *data, Evas_Object *obj __UNUSED__, void *event_info __UN
 }
 
 static void
-my_bt_38_alpha_off(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+my_bt_38_alpha_off(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win = data;
    Evas_Object *bg = evas_object_data_get(win, "bg");
@@ -29,15 +30,50 @@ my_bt_38_alpha_off(void *data, Evas_Object *obj __UNUSED__, void *event_info __U
    elm_win_alpha_set(win, EINA_FALSE);
 }
 
+static Eina_Bool
+_unic(void *data)
+{
+   printf("activate\n");
+   elm_win_activate(data);
+   return EINA_FALSE;
+}
+
+static Eina_Bool
+_unwith(void *data)
+{
+   printf("show\n");
+   evas_object_show(data);
+   elm_win_activate(data);
+   return EINA_FALSE;
+}
+
 static void
-my_ck_38_resize(void *data __UNUSED__, Evas_Object *obj, void *event_info __UNUSED__)
+my_bt_38_iconify(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   Evas_Object *win = data;
+   printf("iconify, current %i\n", elm_win_iconified_get(win));
+   elm_win_iconified_set(win, EINA_TRUE);
+   ecore_timer_add(10.0, _unic, win);
+}
+
+static void
+my_bt_38_withdraw(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   Evas_Object *win = data;
+   printf("withdraw, current %i\n", elm_win_withdrawn_get(win));
+   elm_win_withdrawn_set(win, EINA_TRUE);
+   ecore_timer_add(10.0, _unwith, win);
+}
+
+static void
+my_ck_38_resize(void *data EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
 //   Evas_Object *win = data;
    rotate_with_resize = elm_check_state_get(obj);
 }
 
 static void
-my_bt_38_rot_0(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+my_bt_38_rot_0(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win = data;
    if (rotate_with_resize)
@@ -47,7 +83,7 @@ my_bt_38_rot_0(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSE
 }
 
 static void
-my_bt_38_rot_90(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+my_bt_38_rot_90(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win = data;
    if (rotate_with_resize)
@@ -57,7 +93,7 @@ my_bt_38_rot_90(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUS
 }
 
 static void
-my_bt_38_rot_180(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+my_bt_38_rot_180(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win = data;
    if (rotate_with_resize)
@@ -67,7 +103,7 @@ my_bt_38_rot_180(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNU
 }
 
 static void
-my_bt_38_rot_270(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+my_bt_38_rot_270(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win = data;
    if (rotate_with_resize)
@@ -77,7 +113,23 @@ my_bt_38_rot_270(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNU
 }
 
 static void
-my_win_move(void *data __UNUSED__, Evas_Object *obj, void *event_info __UNUSED__)
+my_ck_38_fullscreen(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
+{
+   Evas_Object *win = data;
+   fullscreen = elm_check_state_get(obj);
+   elm_win_fullscreen_set(win, fullscreen);
+}
+
+static void
+my_ck_38_borderless(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
+{
+   Evas_Object *win = data;
+   Eina_Bool borderless = elm_check_state_get(obj);
+   elm_win_borderless_set(win, borderless);
+}
+
+static void
+my_win_move(void *data EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    Evas_Coord x, y;
    elm_win_screen_position_get(obj, &x, &y);
@@ -85,7 +137,7 @@ my_win_move(void *data __UNUSED__, Evas_Object *obj, void *event_info __UNUSED__
 }
 
 static void
-_win_resize(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj, void *event_info __UNUSED__)
+_win_resize(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    Evas_Coord w, h;
    evas_object_geometry_get(obj, NULL, NULL, &w, &h);
@@ -93,25 +145,25 @@ _win_resize(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj, void *e
 }
 
 static void
-_win_foc_in(void *data __UNUSED__, Evas *e __UNUSED__, void *event_info __UNUSED__)
+_win_foc_in(void *data EINA_UNUSED, Evas *e EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    printf("FOC IN\n");
 }
 
 static void
-_win_foc_out(void *data __UNUSED__, Evas *e __UNUSED__, void *event_info __UNUSED__)
+_win_foc_out(void *data EINA_UNUSED, Evas *e EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    printf("FOC OUT\n");
 }
 
 static void
-_close_win(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+_close_win(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    evas_object_del(data);
 }
 
 void
-test_win_state(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+test_win_state(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win, *bg, *sl, *bx, *bx2, *bt, *ck;
 
@@ -124,8 +176,8 @@ test_win_state(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_i
    elm_win_autodel_set(win, EINA_TRUE);
 
    bg = elm_bg_add(win);
-   elm_win_resize_object_add(win, bg);
    evas_object_size_hint_weight_set(bg, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   elm_win_resize_object_add(win, bg);
    evas_object_show(bg);
    evas_object_data_set(win, "bg", bg);
 
@@ -156,6 +208,22 @@ test_win_state(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_i
    elm_box_pack_end(bx2, bt);
    evas_object_show(bt);
 
+   bt = elm_button_add(win);
+   elm_object_text_set(bt, "Iconify");
+   evas_object_smart_callback_add(bt, "clicked", my_bt_38_iconify, win);
+   evas_object_size_hint_fill_set(bt, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   evas_object_size_hint_weight_set(bt, EVAS_HINT_EXPAND, 0.0);
+   elm_box_pack_end(bx2, bt);
+   evas_object_show(bt);
+
+   bt = elm_button_add(win);
+   elm_object_text_set(bt, "Withdraw");
+   evas_object_smart_callback_add(bt, "clicked", my_bt_38_withdraw, win);
+   evas_object_size_hint_fill_set(bt, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   evas_object_size_hint_weight_set(bt, EVAS_HINT_EXPAND, 0.0);
+   elm_box_pack_end(bx2, bt);
+   evas_object_show(bt);
+
    elm_box_pack_end(bx, bx2);
    evas_object_show(bx2);
 
@@ -189,6 +257,24 @@ test_win_state(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_i
    evas_object_show(ck);
    elm_box_pack_end(bx, ck);
 
+   ck = elm_check_add(win);
+   elm_object_text_set(ck, "fullscreen");
+   elm_check_state_set(ck, fullscreen);
+   evas_object_smart_callback_add(ck, "changed", my_ck_38_fullscreen, win);
+   evas_object_size_hint_weight_set(ck, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   evas_object_size_hint_align_set(ck, 0.02, 0.99);
+   evas_object_show(ck);
+   elm_box_pack_end(bx, ck);
+
+   ck = elm_check_add(win);
+   elm_object_text_set(ck, "borderless");
+   elm_check_state_set(ck, fullscreen);
+   evas_object_smart_callback_add(ck, "changed", my_ck_38_borderless, win);
+   evas_object_size_hint_weight_set(ck, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   evas_object_size_hint_align_set(ck, 0.02, 0.99);
+   evas_object_show(ck);
+   elm_box_pack_end(bx, ck);
+
    bx2 = elm_box_add(win);
    elm_box_horizontal_set(bx2, EINA_TRUE);
    elm_box_homogeneous_set(bx2, EINA_TRUE);
@@ -235,7 +321,7 @@ test_win_state(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_i
 }
 
 void
-test_win_state2(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+test_win_state2(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Evas_Object *win, *bg, *sl, *bx, *bx2, *bt, *ck;
    char buf[PATH_MAX];
@@ -250,8 +336,8 @@ test_win_state2(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_
    bg = elm_bg_add(win);
    snprintf(buf, sizeof(buf), "%s/images/sky_02.jpg", elm_app_data_dir_get());
    elm_bg_file_set(bg, buf, NULL);
-   elm_win_resize_object_add(win, bg);
    evas_object_size_hint_weight_set(bg, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   elm_win_resize_object_add(win, bg);
    evas_object_show(bg);
    evas_object_data_set(win, "bg", bg);
 
@@ -366,4 +452,3 @@ test_win_state2(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_
    evas_object_resize(win, 320, 480);
    evas_object_show(win);
 }
-#endif
