@@ -18,10 +18,11 @@ external_bubble_state_set(void *data __UNUSED__, Evas_Object *obj, const void *f
    else if (from_params) p = from_params;
    else return;
 
-   if (p->label) elm_bubble_label_set(obj, p->label);
-   if (p->icon) elm_bubble_icon_set(obj, p->icon);
-   if (p->info) elm_bubble_info_set(obj, p->info);
-   if (p->content) elm_bubble_content_set(obj, p->content);
+   if (p->label) elm_object_text_set(obj, p->label);
+   if (p->icon)
+     elm_object_part_content_set(obj, "icon", p->icon);
+   if (p->info) elm_object_part_text_set(obj, "info", p->info);
+   if (p->content) elm_object_content_set(obj, p->content);
 }
 
 static Eina_Bool
@@ -31,7 +32,7 @@ external_bubble_param_set(void *data __UNUSED__, Evas_Object *obj, const Edje_Ex
      {
 	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
 	  {
-	     elm_bubble_label_set(obj, param->s);
+	     elm_object_text_set(obj, param->s);
 	     return EINA_TRUE;
 	  }
      }
@@ -41,15 +42,15 @@ external_bubble_param_set(void *data __UNUSED__, Evas_Object *obj, const Edje_Ex
 	  {
 	     Evas_Object *icon = external_common_param_icon_get(obj, param);
 	     if ((strcmp(param->s, "")) && (!icon)) return EINA_FALSE;
-	     elm_bubble_icon_set(obj, icon);
-	     return EINA_TRUE;
+	     elm_object_part_content_set(obj, "icon", icon);
+        return EINA_TRUE;
 	  }
      }
    else if (!strcmp(param->name, "info"))
      {
 	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
 	  {
-	     elm_bubble_info_set(obj, param->s);
+	     elm_object_part_text_set(obj, "info", param->s);
 	     return EINA_TRUE;
 	  }
      }
@@ -60,7 +61,7 @@ external_bubble_param_set(void *data __UNUSED__, Evas_Object *obj, const Edje_Ex
 	     Evas_Object *content = \
 		    external_common_param_edje_object_get(obj, param);
 	     if ((strcmp(param->s, "")) && (!content)) return EINA_FALSE;
-	     elm_bubble_content_set(obj, content);
+	     elm_object_content_set(obj, content);
 	     return EINA_TRUE;
 	  }
      }
@@ -78,7 +79,7 @@ external_bubble_param_get(void *data __UNUSED__, const Evas_Object *obj, Edje_Ex
      {
 	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
 	  {
-	     param->s = elm_bubble_label_get(obj);
+	     param->s = elm_object_text_get(obj);
 	     return EINA_TRUE;
 	  }
      }
@@ -91,7 +92,7 @@ external_bubble_param_get(void *data __UNUSED__, const Evas_Object *obj, Edje_Ex
      {
 	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
 	  {
-	     param->s = elm_bubble_info_get(obj);
+	     param->s = elm_object_part_text_get(obj, "info");
 	     return EINA_TRUE;
 	  }
      }
@@ -136,8 +137,10 @@ external_bubble_params_parse(void *data __UNUSED__, Evas_Object *obj, const Eina
 static Evas_Object *external_bubble_content_get(void *data __UNUSED__,
 		const Evas_Object *obj __UNUSED__, const char *content __UNUSED__)
 {
-	ERR("No content.");
-	return NULL;
+   if (!strcmp(content, "content"))
+     return elm_object_content_get(obj);
+   ERR("unknown content '%s'", content);
+   return NULL;
 }
 
 static void
