@@ -29,8 +29,8 @@ external_fileselector_button_state_set(void *data __UNUSED__, Evas_Object *obj,
    else return;
 
    if (p->label)
-     elm_fileselector_button_label_set(obj, p->label);
-   if (p->icon) elm_fileselector_button_icon_set(obj, p->icon);
+     elm_object_text_set(obj, p->label);
+   if (p->icon) elm_object_part_content_set(obj, "icon", p->icon);
    if (p->fs.path) elm_fileselector_button_path_set(obj, p->fs.path);
    if (p->fs.is_save_set)
      elm_fileselector_button_is_save_set(obj, p->fs.is_save);
@@ -47,61 +47,61 @@ external_fileselector_button_param_set(void *data __UNUSED__, Evas_Object *obj,
 {
    if (!strcmp(param->name, "label"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
-	  {
-	     elm_fileselector_button_label_set(obj, param->s);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
+          {
+             elm_object_text_set(obj, param->s);
+             return EINA_TRUE;
+          }
      }
    else if (!strcmp(param->name, "icon"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
-	  {
-	     Evas_Object *icon = external_common_param_icon_get(obj, param);
-	     if ((strcmp(param->s, "")) && (!icon)) return EINA_FALSE;
-	     elm_fileselector_button_icon_set(obj, icon);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
+          {
+             Evas_Object *icon = external_common_param_icon_get(obj, param);
+             if ((strcmp(param->s, "")) && (!icon)) return EINA_FALSE;
+             elm_object_part_content_set(obj, "icon", icon);
+             return EINA_TRUE;
+          }
      }
    else if (!strcmp(param->name, "path"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
-	  {
-	     elm_fileselector_button_path_set(obj, param->s);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
+          {
+             elm_fileselector_button_path_set(obj, param->s);
+             return EINA_TRUE;
+          }
      }
    else if (!strcmp(param->name, "save"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
-	  {
-	     elm_fileselector_button_is_save_set(obj, param->i);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
+          {
+             elm_fileselector_button_is_save_set(obj, param->i);
+             return EINA_TRUE;
+          }
      }
    else if (!strcmp(param->name, "folder only"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
-	  {
-	     elm_fileselector_button_folder_only_set(obj, param->i);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
+          {
+             elm_fileselector_button_folder_only_set(obj, param->i);
+             return EINA_TRUE;
+          }
      }
    else if (!strcmp(param->name, "expandable"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
-	  {
-	     elm_fileselector_button_expandable_set(obj, param->i);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
+          {
+             elm_fileselector_button_expandable_set(obj, param->i);
+             return EINA_TRUE;
+          }
      }
    else if (!strcmp(param->name, "inwin mode"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
-	  {
-	     elm_fileselector_button_inwin_mode_set(obj, param->i);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
+          {
+             elm_fileselector_button_inwin_mode_set(obj, param->i);
+             return EINA_TRUE;
+          }
      }
 
    ERR("unknown parameter '%s' of type '%s'",
@@ -115,56 +115,56 @@ external_fileselector_button_param_get(void *data __UNUSED__, const Evas_Object
 {
    if (!strcmp(param->name, "label"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
-	  {
-	     param->s = elm_fileselector_button_label_get(obj);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
+          {
+             param->s = elm_object_text_get(obj);
+             return EINA_TRUE;
+          }
      }
    else if (!strcmp(param->name, "icon"))
      {
-	/* not easy to get icon name back from live object */
-	return EINA_FALSE;
+        /* not easy to get icon name back from live object */
+        return EINA_FALSE;
      }
    else if (!strcmp(param->name, "path"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
-	  {
-	     param->s = elm_fileselector_button_path_get(obj);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
+          {
+             param->s = elm_fileselector_button_path_get(obj);
+             return EINA_TRUE;
+          }
      }
    else if (!strcmp(param->name, "save"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
-	  {
-	     param->i = elm_fileselector_button_is_save_get(obj);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
+          {
+             param->i = elm_fileselector_button_is_save_get(obj);
+             return EINA_TRUE;
+          }
      }
    else if (!strcmp(param->name, "folder only"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
-	  {
-	     param->i = elm_fileselector_button_folder_only_get(obj);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
+          {
+             param->i = elm_fileselector_button_folder_only_get(obj);
+             return EINA_TRUE;
+          }
      }
    else if (!strcmp(param->name, "expandable"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
-	  {
-	     param->i = elm_fileselector_button_expandable_get(obj);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
+          {
+             param->i = elm_fileselector_button_expandable_get(obj);
+             return EINA_TRUE;
+          }
      }
    else if (!strcmp(param->name, "inwin mode"))
      {
-	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
-	  {
-	     param->i = elm_fileselector_button_inwin_mode_get(obj);
-	     return EINA_TRUE;
-	  }
+        if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
+          {
+             param->i = elm_fileselector_button_inwin_mode_get(obj);
+             return EINA_TRUE;
+          }
      }
 
    ERR("unknown parameter '%s' of type '%s'",
@@ -188,40 +188,39 @@ external_fileselector_button_params_parse(void *data __UNUSED__, Evas_Object *ob
 
    EINA_LIST_FOREACH(params, l, param)
      {
-	if (!strcmp(param->name, "path"))
-	  mem->fs.path = eina_stringshare_add(param->s);
-	else if (!strcmp(param->name, "save"))
-	  {
-	     mem->fs.is_save = !!param->i;
-	     mem->fs.is_save_set = EINA_TRUE;
-	  }
-	else if (!strcmp(param->name, "folder only"))
-	  {
-	     mem->fs.folder_only = !!param->i;
-	     mem->fs.folder_only_set = EINA_TRUE;
-	  }
-	else if (!strcmp(param->name, "expandable"))
-	  {
-	     mem->fs.expandable = !!param->i;
-	     mem->fs.expandable_set = EINA_TRUE;
-	  }
-	else if (!strcmp(param->name, "inwin mode"))
-	  {
-	     mem->fs.inwin_mode = !!param->i;
-	     mem->fs.inwin_mode_set = EINA_TRUE;
-	  }
-	else if (!strcmp(param->name, "label"))
-	  mem->label = eina_stringshare_add(param->s);
+        if (!strcmp(param->name, "path"))
+          mem->fs.path = eina_stringshare_add(param->s);
+        else if (!strcmp(param->name, "save"))
+          {
+             mem->fs.is_save = !!param->i;
+             mem->fs.is_save_set = EINA_TRUE;
+          }
+        else if (!strcmp(param->name, "folder only"))
+          {
+             mem->fs.folder_only = !!param->i;
+             mem->fs.folder_only_set = EINA_TRUE;
+          }
+        else if (!strcmp(param->name, "expandable"))
+          {
+             mem->fs.expandable = !!param->i;
+             mem->fs.expandable_set = EINA_TRUE;
+          }
+        else if (!strcmp(param->name, "inwin mode"))
+          {
+             mem->fs.inwin_mode = !!param->i;
+             mem->fs.inwin_mode_set = EINA_TRUE;
+          }
+        else if (!strcmp(param->name, "label"))
+          mem->label = eina_stringshare_add(param->s);
      }
 
    return mem;
 }
 
-static Evas_Object *external_fileselector_button_content_get(void *data __UNUSED__,
-		const Evas_Object *obj __UNUSED__, const char *content __UNUSED__)
+static Evas_Object *external_fileselector_button_content_get(void *data __UNUSED__, const Evas_Object *obj __UNUSED__, const char *content __UNUSED__)
 {
-	ERR("No content.");
-	return NULL;
+   ERR("No content.");
+   return NULL;
 }
 
  static void
