@@ -20,9 +20,9 @@ external_radio_state_set(void *data __UNUSED__, Evas_Object *obj, const void *fr
    else return;
 
    if (p->label)
-     elm_radio_label_set(obj, p->label);
+     elm_object_text_set(obj, p->label);
    if (p->icon)
-     elm_radio_icon_set(obj, p->icon);
+     elm_object_part_content_set(obj, "icon", p->icon);
    if (p->value_exists)
      elm_radio_state_value_set(obj, p->value);
    if (p->group_name)
@@ -40,7 +40,7 @@ external_radio_param_set(void *data __UNUSED__, Evas_Object *obj, const Edje_Ext
      {
 	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
 	  {
-	     elm_radio_label_set(obj, param->s);
+	     elm_object_text_set(obj, param->s);
 	     return EINA_TRUE;
 	  }
      }
@@ -50,7 +50,7 @@ external_radio_param_set(void *data __UNUSED__, Evas_Object *obj, const Edje_Ext
 	  {
 	     Evas_Object *icon = external_common_param_icon_get(obj, param);
 	     if ((strcmp(param->s, "")) && (!icon)) return EINA_FALSE;
-	     elm_radio_icon_set(obj, icon);
+	     elm_object_part_content_set(obj, "icon", icon);
 	     return EINA_TRUE;
 	  }
      }
@@ -86,7 +86,7 @@ external_radio_param_get(void *data __UNUSED__, const Evas_Object *obj, Edje_Ext
      {
 	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
 	  {
-	     param->s = elm_radio_label_get(obj);
+	     param->s = elm_object_text_get(obj);
 	     return EINA_TRUE;
 	  }
      }
