@@ -4,10 +4,27 @@
 #include "Elementary.h"
 #include "elm_priv.h"
 
+#undef CRITICAL
+#undef ERR
+#undef WRN
+#undef INF
+#undef DBG
+
+#define CRITICAL(...) EINA_LOG_DOM_CRIT(_elm_ext_log_dom, __VA_ARGS__)
+#define ERR(...)      EINA_LOG_DOM_ERR (_elm_ext_log_dom, __VA_ARGS__)
+#define WRN(...)      EINA_LOG_DOM_WARN(_elm_ext_log_dom, __VA_ARGS__)
+#define INF(...)      EINA_LOG_DOM_INFO(_elm_ext_log_dom, __VA_ARGS__)
+#define DBG(...)      EINA_LOG_DOM_DBG (_elm_ext_log_dom, __VA_ARGS__)
+
 typedef struct {
     const char *style;
+    Eina_Bool disabled:1;
+    Eina_Bool disabled_exists:1;
 } Elm_Params;
 
+extern int _elm_ext_log_dom;
+
+void external_elm_init(void);
 void external_signal(void *data, Evas_Object *obj, const char *signal, const char *source);
 void external_signals_proxy(Evas_Object *obj, Evas_Object *edje, const char *part_name);
 const char *external_translate(void *data, const char *orig);
@@ -89,6 +106,7 @@ static Evas_Object *                                \
 external_##type_name##_add(void *data __UNUSED__, Evas *evas __UNUSED__, Evas_Object *edje, const Eina_List *params __UNUSED__, const char *part_name) \
 {									\
    Evas_Object *parent, *obj;						\
+   external_elm_init();                                                 \
    parent = elm_widget_parent_widget_get(edje);			\
    if (!parent) parent = edje;						\
    obj = elm_##type_name##_add(parent);				\
@@ -113,4 +131,5 @@ external_##type_name##_icon_add(void *data __UNUSED__, Evas *e) {   \
 }
 
 #define DEFINE_EXTERNAL_COMMON_PARAMS           \
-    EDJE_EXTERNAL_PARAM_INFO_STRING_DEFAULT("style", "default")
+    EDJE_EXTERNAL_PARAM_INFO_STRING_DEFAULT("style", "default"), \
+    EDJE_EXTERNAL_PARAM_INFO_BOOL_DEFAULT("disabled", EINA_FALSE)
