@@ -3,23 +3,22 @@
 
 #include <Elementary.h>
 
-static void _print(void *data, Evas_Object *obj, void *event_info);
+static void
+_print(void *data, Evas_Object *obj, void *event_info)
+{
+   printf("check %smarked\n", *((Eina_Bool*)data) ? "" : "un");
+}
 
 EAPI_MAIN int
 elm_main(int argc, char **argv)
 {
-   Evas_Object *win, *bg, *cb, *cb2, *icon;
+   Evas_Object *win, *cb, *cb2, *icon;
    Eina_Bool value;
 
-   win = elm_win_add(NULL, "check", ELM_WIN_BASIC);
-   elm_win_title_set(win, "Check");
-   elm_win_autodel_set(win, EINA_TRUE);
    elm_policy_set(ELM_POLICY_QUIT, ELM_POLICY_QUIT_LAST_WINDOW_CLOSED);
 
-   bg = elm_bg_add(win);
-   evas_object_size_hint_weight_set(bg, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
-   elm_win_resize_object_add(win, bg);
-   evas_object_show(bg);
+   win = elm_win_util_standard_add("check", "Check");
+   elm_win_autodel_set(win, EINA_TRUE);
 
    cb = elm_check_add(win);
    elm_object_text_set(cb, "checkbox");
@@ -52,8 +51,3 @@ elm_main(int argc, char **argv)
 }
 ELM_MAIN()
 
-static void
-_print(void *data, Evas_Object *obj, void *event_info)
-{
-   printf("check %smarked\n", *((Eina_Bool*)data) ? "" : "un");
-}
