@@ -9,19 +9,12 @@ static void _timeout(void *data, Evas_Object *obj, void *event_info);
 EAPI_MAIN int
 elm_main(int argc, char **argv)
 {
-   Evas_Object *win, *bg, *popup, *content;
+   Evas_Object *win, *popup, *content;
 
-   win = elm_win_add(NULL, "popup", ELM_WIN_BASIC);
-   elm_win_title_set(win, "Popup");
+   win = elm_win_util_standard_add("popup", "Popup");
    elm_win_autodel_set(win, EINA_TRUE);
    elm_policy_set(ELM_POLICY_QUIT, ELM_POLICY_QUIT_LAST_WINDOW_CLOSED);
 
-   bg = elm_bg_add(win);
-   elm_bg_color_set(bg, 128, 128, 128);
-   evas_object_size_hint_weight_set(bg, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
-   elm_win_resize_object_add(win, bg);
-   evas_object_show(bg);
-
    content = elm_label_add(win);
    elm_object_text_set(content, "<align=center>Content</align>");
 
