@@ -6,16 +6,12 @@
 EAPI_MAIN int
 elm_main(int argc, char **argv)
 {
-   Evas_Object *win, *bg, *label, *table;
+   Evas_Object *win, *label, *table;
 
-   win = elm_win_add(NULL, "table", ELM_WIN_BASIC);
-   elm_win_title_set(win, "Table");
-   elm_win_autodel_set(win, EINA_TRUE);
    elm_policy_set(ELM_POLICY_QUIT, ELM_POLICY_QUIT_LAST_WINDOW_CLOSED);
 
-   bg = elm_bg_add(win);
-   elm_win_resize_object_add(win, bg);
-   evas_object_show(bg);
+   win = elm_win_util_standard_add("table", "Table");
+   elm_win_autodel_set(win, EINA_TRUE);
 
    table = elm_table_add(win);
    elm_win_resize_object_add(win, table);
