@@ -1,13 +1,17 @@
+#ifdef HAVE_CONFIG_H
+# include "elementary_config.h"
+#endif
+
 #include <Elementary.h>
 #include "elm_priv.h"
 #include "els_box.h"
 #include "elm_widget_box.h"
 
-EAPI const char ELM_BOX_SMART_NAME[] = "elm_box";
+EAPI Eo_Op ELM_OBJ_BOX_BASE_ID = EO_NOOP;
 
-EVAS_SMART_SUBCLASS_NEW
-  (ELM_BOX_SMART_NAME, _elm_box, Elm_Box_Smart_Class,
-  Elm_Widget_Smart_Class, elm_widget_smart_class_get, NULL);
+#define MY_CLASS ELM_OBJ_BOX_CLASS
+#define MY_CLASS_NAME "Elm_Box"
+#define MY_CLASS_NAME_LEGACY "elm_box"
 
 static const char SIG_CHILD_ADDED[] = "child,added";
 static const char SIG_CHILD_REMOVED[] = "child,removed";
@@ -44,15 +48,24 @@ _child_removed_cb_proxy(void *data,
    evas_object_smart_callback_call(box, SIG_CHILD_REMOVED, child);
 }
 
-static Eina_Bool
-_elm_box_smart_focus_next(const Evas_Object *obj,
-                          Elm_Focus_Direction dir,
-                          Evas_Object **next)
+static void
+_elm_box_smart_focus_next_manager_is(Eo *obj EINA_UNUSED, void *_pd EINA_UNUSED, va_list *list)
+{
+   Eina_Bool *ret = va_arg(*list, Eina_Bool *);
+   *ret = EINA_TRUE;
+}
+
+static void
+_elm_box_smart_focus_next(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
 {
    const Eina_List *items;
    void *(*list_data_get)(const Eina_List *list);
 
-   ELM_BOX_DATA_GET(obj, sd);
+   Elm_Focus_Direction dir = va_arg(*list, Elm_Focus_Direction);
+   Evas_Object **next = va_arg(*list, Evas_Object **);
+   Eina_Bool *ret = va_arg(*list, Eina_Bool *);
+   Eina_Bool int_ret;
+   if (ret) *ret = EINA_FALSE;
 
    /* Focus chain */
    /* TODO: Change this to use other chain */
@@ -60,56 +73,73 @@ _elm_box_smart_focus_next(const Evas_Object *obj,
      list_data_get = eina_list_data_get;
    else
      {
+        ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
         Evas_Object_Box_Data *bd =
-          evas_object_smart_data_get(ELM_WIDGET_DATA(sd)->resize_obj);
+          evas_object_smart_data_get(wd->resize_obj);
 
         items = bd->children;
         list_data_get = _elm_box_list_data_get;
 
-        if (!items) return EINA_FALSE;
+        if (!items) return;
      }
 
-   return elm_widget_focus_list_next_get(obj, items, list_data_get, dir, next);
+   int_ret = elm_widget_focus_list_next_get(obj, items, list_data_get, dir, next);
+   if (ret) *ret = int_ret;
 }
 
-static Eina_Bool
-_elm_box_smart_focus_direction(const Evas_Object *obj,
-                               const Evas_Object *base,
-                               double degree,
-                               Evas_Object **direction,
-                               double *weight)
+static void
+_elm_box_smart_focus_direction_manager_is(Eo *obj EINA_UNUSED, void *_pd EINA_UNUSED, va_list *list)
 {
+   Eina_Bool *ret = va_arg(*list, Eina_Bool *);
+   *ret = EINA_TRUE;
+}
+
+static void
+_elm_box_smart_focus_direction(Eo *obj EINA_UNUSED, void *_pd EINA_UNUSED, va_list *list)
+{
+   Evas_Object *base = va_arg(*list, Evas_Object *);
+   double degree = va_arg(*list, double);
+   Evas_Object **direction = va_arg(*list, Evas_Object **);
+   double *weight = va_arg(*list, double *);
+   Eina_Bool *ret = va_arg(*list, Eina_Bool *);
+   if (ret) *ret = EINA_FALSE;
+   Eina_Bool int_ret;
+
    const Eina_List *items;
    void *(*list_data_get)(const Eina_List *list);
 
-   ELM_BOX_DATA_GET(obj, sd);
-
    if ((items = elm_widget_focus_custom_chain_get(obj)))
      list_data_get = eina_list_data_get;
    else
      {
+        ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
         Evas_Object_Box_Data *bd =
-          evas_object_smart_data_get(ELM_WIDGET_DATA(sd)->resize_obj);
+          evas_object_smart_data_get(wd->resize_obj);
 
         items = bd->children;
         list_data_get = _elm_box_list_data_get;
 
-        if (!items) return EINA_FALSE;
+        if (!items) return;
      }
-   return elm_widget_focus_list_direction_get
+   int_ret = elm_widget_focus_list_direction_get
             (obj, base, items, list_data_get, degree, direction, weight);
+   if (ret) *ret = int_ret;
 }
 
-static Eina_Bool
-_elm_box_smart_theme(Evas_Object *obj)
+static void
+_elm_box_smart_theme(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
 {
-   ELM_BOX_DATA_GET(obj, sd);
+   Eina_Bool *ret = va_arg(*list, Eina_Bool *);
+   if (ret) *ret = EINA_FALSE;
+   Eina_Bool int_ret = EINA_FALSE;
 
-   if (!_elm_box_parent_sc->theme(obj)) return EINA_FALSE;
+   eo_do_super(obj, MY_CLASS, elm_wdg_theme(&int_ret));
+   if (!int_ret) return;
 
-   evas_object_smart_calculate(ELM_WIDGET_DATA(sd)->resize_obj);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
+   evas_object_smart_calculate(wd->resize_obj);
 
-   return EINA_TRUE;
+   if (ret) *ret = EINA_TRUE;
 }
 
 static void
@@ -119,11 +149,17 @@ _sizing_eval(Evas_Object *obj)
    Evas_Coord w, h;
 
    ELM_BOX_DATA_GET(obj, sd);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
+
+   if (sd->delete_me)
+     return;
 
    evas_object_size_hint_min_get
-     (ELM_WIDGET_DATA(sd)->resize_obj, &minw, &minh);
+     (wd->resize_obj, &minw, &minh);
+
    evas_object_size_hint_max_get
-     (ELM_WIDGET_DATA(sd)->resize_obj, &maxw, &maxh);
+     (wd->resize_obj, &maxw, &maxh);
+
    evas_object_size_hint_min_set(obj, minw, minh);
    evas_object_size_hint_max_set(obj, maxw, maxh);
 
@@ -144,15 +180,20 @@ _on_size_hints_changed(void *data,
    _sizing_eval(data);
 }
 
-static Eina_Bool
-_elm_box_smart_sub_object_del(Evas_Object *obj,
-                              Evas_Object *child)
+static void
+_elm_box_smart_sub_object_del(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
 {
-   if (!_elm_box_parent_sc->sub_object_del(obj, child)) return EINA_FALSE;
+   Evas_Object *child = va_arg(*list, Evas_Object *);
+   Eina_Bool *ret = va_arg(*list, Eina_Bool *);
+   if (ret) *ret = EINA_FALSE;
+   Eina_Bool int_ret = EINA_FALSE;
+
+   eo_do_super(obj, MY_CLASS, elm_wdg_sub_object_del(child, &int_ret));
+   if (!int_ret) return;
 
    _sizing_eval(obj);
 
-   return EINA_TRUE;
+   if (ret) *ret = EINA_TRUE;
 }
 
 static void
@@ -200,7 +241,7 @@ _transition_layout_child_removed(void *data,
    Transition_Animation_Data *tad;
    Elm_Box_Transition *layout_data = data;
 
-   EINA_LIST_FOREACH (layout_data->objs, l, tad)
+   EINA_LIST_FOREACH(layout_data->objs, l, tad)
      {
         if (tad->obj == event_info)
           {
@@ -238,7 +279,7 @@ _transition_layout_calculate_coords(Evas_Object *obj,
    layout_data->initial_time = curtime;
 
    evas_object_geometry_get(obj, &x, &y, &w, &h);
-   EINA_LIST_FOREACH (layout_data->objs, l, tad)
+   EINA_LIST_FOREACH(layout_data->objs, l, tad)
      {
         evas_object_geometry_get(tad->obj, &tad->start.x, &tad->start.y,
                                  &tad->start.w, &tad->start.h);
@@ -246,7 +287,7 @@ _transition_layout_calculate_coords(Evas_Object *obj,
         tad->start.y = tad->start.y - y;
      }
    layout_data->end.layout(obj, priv, layout_data->end.data);
-   EINA_LIST_FOREACH (layout_data->objs, l, tad)
+   EINA_LIST_FOREACH(layout_data->objs, l, tad)
      {
         evas_object_geometry_get(tad->obj, &tad->end.x, &tad->end.y,
                                  &tad->end.w, &tad->end.h);
@@ -263,15 +304,15 @@ _transition_layout_load_children_list(Evas_Object_Box_Data *priv,
    Evas_Object_Box_Option *opt;
    Transition_Animation_Data *tad;
 
-   EINA_LIST_FREE (layout_data->objs, tad)
+   EINA_LIST_FREE(layout_data->objs, tad)
      free(tad);
 
-   EINA_LIST_FOREACH (priv->children, l, opt)
+   EINA_LIST_FOREACH(priv->children, l, opt)
      {
         tad = calloc(1, sizeof(Transition_Animation_Data));
         if (!tad)
           {
-             EINA_LIST_FREE (layout_data->objs, tad)
+             EINA_LIST_FREE(layout_data->objs, tad)
                free(tad);
              layout_data->objs = NULL;
              return EINA_FALSE;
@@ -319,11 +360,7 @@ _transition_layout_animation_stop(Elm_Box_Transition *layout_data)
 {
    layout_data->animation_ended = EINA_TRUE;
 
-   if (layout_data->animator)
-     {
-        ecore_animator_del(layout_data->animator);
-        layout_data->animator = NULL;
-     }
+   ELM_SAFE_FREE(layout_data->animator, ecore_animator_del);
 
    if (layout_data->transition_end_cb)
      layout_data->transition_end_cb(layout_data->transition_end_data);
@@ -344,7 +381,7 @@ _transition_layout_animation_exec(Evas_Object *obj,
    progress = (curtime - layout_data->initial_time) / layout_data->duration;
    evas_object_geometry_get(obj, &x, &y, &w, &h);
 
-   EINA_LIST_FOREACH (layout_data->objs, l, tad)
+   EINA_LIST_FOREACH(layout_data->objs, l, tad)
      {
         cur_x = x + tad->start.x + ((tad->end.x - tad->start.x) * progress);
         cur_y = y + tad->start.y + ((tad->end.y - tad->start.y) * progress);
@@ -356,122 +393,113 @@ _transition_layout_animation_exec(Evas_Object *obj,
 }
 
 static void
-_elm_box_smart_add(Evas_Object *obj)
+_elm_box_smart_add(Eo *obj, void *_pd EINA_UNUSED, va_list *list EINA_UNUSED)
 {
-   EVAS_SMART_DATA_ALLOC(obj, Elm_Box_Smart_Data);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
+   elm_widget_resize_object_set(obj,
+                                evas_object_box_add(evas_object_evas_get(obj)),
+                                EINA_TRUE);
 
-   ELM_WIDGET_DATA(priv)->resize_obj =
-     evas_object_box_add(evas_object_evas_get(obj));
-   evas_object_box_layout_set
-     (ELM_WIDGET_DATA(priv)->resize_obj, _elm_box_custom_layout, obj, NULL);
+   evas_object_box_layout_set(wd->resize_obj, _elm_box_custom_layout,
+                              obj, NULL);
 
-   evas_object_event_callback_add
-     (ELM_WIDGET_DATA(priv)->resize_obj, EVAS_CALLBACK_CHANGED_SIZE_HINTS,
-     _on_size_hints_changed, obj);
+   evas_object_event_callback_add(wd->resize_obj,
+                                  EVAS_CALLBACK_CHANGED_SIZE_HINTS,
+                                  _on_size_hints_changed, obj);
 
-   _elm_box_parent_sc->base.add(obj);
+   eo_do_super(obj, MY_CLASS, evas_obj_smart_add());
+   elm_widget_sub_object_parent_add(obj);
 
-   evas_object_smart_callback_add
-     (ELM_WIDGET_DATA(priv)->resize_obj, SIG_CHILD_ADDED,
-     _child_added_cb_proxy, obj);
-   evas_object_smart_callback_add
-     (ELM_WIDGET_DATA(priv)->resize_obj, SIG_CHILD_REMOVED,
-     _child_removed_cb_proxy, obj);
+   evas_object_smart_callback_add(wd->resize_obj, SIG_CHILD_ADDED,
+                                  _child_added_cb_proxy, obj);
+   evas_object_smart_callback_add(wd->resize_obj, SIG_CHILD_REMOVED,
+                                  _child_removed_cb_proxy, obj);
 
    elm_widget_can_focus_set(obj, EINA_FALSE);
    elm_widget_highlight_ignore_set(obj, EINA_TRUE);
 }
 
 static void
-_elm_box_smart_del(Evas_Object *obj)
+_elm_box_smart_del(Eo *obj, void *_pd, va_list *list EINA_UNUSED)
 {
    Eina_List *l;
    Evas_Object *child;
 
-   ELM_BOX_DATA_GET(obj, sd);
+   Elm_Box_Smart_Data *sd = _pd;
+   sd->delete_me = EINA_TRUE;
 
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
    evas_object_event_callback_del_full
-     (ELM_WIDGET_DATA(sd)->resize_obj, EVAS_CALLBACK_CHANGED_SIZE_HINTS,
+     (wd->resize_obj, EVAS_CALLBACK_CHANGED_SIZE_HINTS,
      _on_size_hints_changed, obj);
 
    /* let's make our box object the *last* to be processed, since it
     * may (smart) parent other sub objects here */
-   EINA_LIST_FOREACH (ELM_WIDGET_DATA(sd)->subobjs, l, child)
+   EINA_LIST_FOREACH (wd->subobjs, l, child)
      {
-        if (child == ELM_WIDGET_DATA(sd)->resize_obj)
+        if (child == wd->resize_obj)
           {
-             ELM_WIDGET_DATA(sd)->subobjs =
-               eina_list_demote_list(ELM_WIDGET_DATA(sd)->subobjs, l);
+             wd->subobjs =
+               eina_list_demote_list(wd->subobjs, l);
              break;
           }
      }
 
-   _elm_box_parent_sc->base.del(obj);
-}
-
-static void
-_elm_box_smart_set_user(Elm_Box_Smart_Class *sc)
-{
-   ELM_WIDGET_CLASS(sc)->base.add = _elm_box_smart_add;
-   ELM_WIDGET_CLASS(sc)->base.del = _elm_box_smart_del;
-
-   ELM_WIDGET_CLASS(sc)->sub_object_del = _elm_box_smart_sub_object_del;
-   ELM_WIDGET_CLASS(sc)->theme = _elm_box_smart_theme;
-   ELM_WIDGET_CLASS(sc)->focus_next = _elm_box_smart_focus_next;
-   ELM_WIDGET_CLASS(sc)->focus_direction = _elm_box_smart_focus_direction;
-}
-
-EAPI const Elm_Box_Smart_Class *
-elm_box_smart_class_get(void)
-{
-   static Elm_Box_Smart_Class _sc =
-     ELM_BOX_SMART_CLASS_INIT_NAME_VERSION(ELM_BOX_SMART_NAME);
-   static const Elm_Box_Smart_Class *class = NULL;
-   Evas_Smart_Class *esc = (Evas_Smart_Class *)&_sc;
-
-   if (class) return class;
-
-   _elm_box_smart_set(&_sc);
-   esc->callbacks = _smart_callbacks;
-   class = &_sc;
-
-   return class;
+   eo_do_super(obj, MY_CLASS, evas_obj_smart_del());
 }
 
 EAPI Evas_Object *
 elm_box_add(Evas_Object *parent)
 {
-   Evas_Object *obj;
-
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-
-   obj = elm_widget_add(_elm_box_smart_class_new(), parent);
-   if (!obj) return NULL;
-
-   if (!elm_widget_sub_object_add(parent, obj))
-     ERR("could not add %p as sub object of %p", obj, parent);
-
+   Evas_Object *obj = eo_add(MY_CLASS, parent);
+   eo_unref(obj);
    return obj;
 }
 
+static void
+_constructor(Eo *obj, void *_pd EINA_UNUSED, va_list *list EINA_UNUSED)
+{
+   eo_do_super(obj, MY_CLASS, eo_constructor());
+   eo_do(obj,
+         evas_obj_type_set(MY_CLASS_NAME_LEGACY),
+         evas_obj_smart_callbacks_descriptions_set(_smart_callbacks, NULL));
+}
+
 EAPI void
 elm_box_horizontal_set(Evas_Object *obj,
                        Eina_Bool horizontal)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_horizontal_set(horizontal));
+}
+
+static void
+_horizontal_set(Eo *obj, void *_pd, va_list *list)
+{
+   Eina_Bool horizontal = va_arg(*list, int);
+   Elm_Box_Smart_Data *sd = _pd;
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    sd->horizontal = !!horizontal;
-   evas_object_smart_calculate(ELM_WIDGET_DATA(sd)->resize_obj);
+   evas_object_smart_calculate(wd->resize_obj);
 }
 
 EAPI Eina_Bool
 elm_box_horizontal_get(const Evas_Object *obj)
 {
    ELM_BOX_CHECK(obj) EINA_FALSE;
-   ELM_BOX_DATA_GET(obj, sd);
+   Eina_Bool ret;
+   eo_do((Eo *) obj, elm_obj_box_horizontal_get(&ret));
+   return ret;
+}
 
-   return sd->horizontal;
+static void
+_horizontal_get(Eo *obj EINA_UNUSED, void *_pd, va_list *list)
+{
+   Eina_Bool *ret = va_arg(*list, Eina_Bool *);
+   const Elm_Box_Smart_Data *sd = _pd;
+   *ret = sd->horizontal;
 }
 
 EAPI void
@@ -479,19 +507,35 @@ elm_box_homogeneous_set(Evas_Object *obj,
                         Eina_Bool homogeneous)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_homogeneous_set(homogeneous));
+}
+
+static void
+_homogeneous_set(Eo *obj, void *_pd, va_list *list)
+{
+   Eina_Bool homogeneous = va_arg(*list, int);
+   Elm_Box_Smart_Data *sd = _pd;
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    sd->homogeneous = !!homogeneous;
-   evas_object_smart_calculate(ELM_WIDGET_DATA(sd)->resize_obj);
+   evas_object_smart_calculate(wd->resize_obj);
 }
 
 EAPI Eina_Bool
 elm_box_homogeneous_get(const Evas_Object *obj)
 {
    ELM_BOX_CHECK(obj) EINA_FALSE;
-   ELM_BOX_DATA_GET(obj, sd);
+   Eina_Bool ret;
+   eo_do((Eo *) obj, elm_obj_box_homogeneous_get(&ret));
+   return ret;
+}
 
-   return sd->homogeneous;
+static void
+_homogeneous_get(Eo *obj EINA_UNUSED, void *_pd, va_list *list)
+{
+   Eina_Bool *ret = va_arg(*list, Eina_Bool *);
+   const Elm_Box_Smart_Data *sd = _pd;
+   *ret = sd->homogeneous;
 }
 
 EAPI void
@@ -499,10 +543,18 @@ elm_box_pack_start(Evas_Object *obj,
                    Evas_Object *subobj)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_pack_start(subobj));
+}
+
+static void
+_pack_start(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
+
+{
+   Evas_Object *subobj = va_arg(*list, Evas_Object *);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    elm_widget_sub_object_add(obj, subobj);
-   evas_object_box_prepend(ELM_WIDGET_DATA(sd)->resize_obj, subobj);
+   evas_object_box_prepend(wd->resize_obj, subobj);
 }
 
 EAPI void
@@ -510,10 +562,17 @@ elm_box_pack_end(Evas_Object *obj,
                  Evas_Object *subobj)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_pack_end(subobj));
+}
+
+static void
+_pack_end(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
+{
+   Evas_Object *subobj = va_arg(*list, Evas_Object *);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    elm_widget_sub_object_add(obj, subobj);
-   evas_object_box_append(ELM_WIDGET_DATA(sd)->resize_obj, subobj);
+   evas_object_box_append(wd->resize_obj, subobj);
 }
 
 EAPI void
@@ -522,11 +581,20 @@ elm_box_pack_before(Evas_Object *obj,
                     Evas_Object *before)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_pack_before(subobj, before));
+}
+
+static void
+_pack_before(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
+{
+   Evas_Object *subobj = va_arg(*list, Evas_Object *);
+   Evas_Object *before = va_arg(*list, Evas_Object *);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    elm_widget_sub_object_add(obj, subobj);
+
    evas_object_box_insert_before
-     (ELM_WIDGET_DATA(sd)->resize_obj, subobj, before);
+     (wd->resize_obj, subobj, before);
 }
 
 EAPI void
@@ -535,21 +603,34 @@ elm_box_pack_after(Evas_Object *obj,
                    Evas_Object *after)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_pack_after(subobj, after));
+}
+
+static void
+_pack_after(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
+{
+   Evas_Object *subobj = va_arg(*list, Evas_Object *);
+   Evas_Object *after = va_arg(*list, Evas_Object *);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    elm_widget_sub_object_add(obj, subobj);
    evas_object_box_insert_after
-     (ELM_WIDGET_DATA(sd)->resize_obj, subobj, after);
+     (wd->resize_obj, subobj, after);
 }
 
 EAPI void
 elm_box_clear(Evas_Object *obj)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_clear());
+}
 
+static void
+_clear(Eo *obj, void *_pd EINA_UNUSED, va_list *list EINA_UNUSED)
+{
    /* EINA_TRUE means to delete objects as well */
-   evas_object_box_remove_all(ELM_WIDGET_DATA(sd)->resize_obj, EINA_TRUE);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
+   evas_object_box_remove_all(wd->resize_obj, EINA_TRUE);
 }
 
 EAPI void
@@ -557,28 +638,42 @@ elm_box_unpack(Evas_Object *obj,
                Evas_Object *subobj)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_unpack(subobj));
 
-   if (evas_object_box_remove(ELM_WIDGET_DATA(sd)->resize_obj, subobj))
+}
+
+static void
+_unpack(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
+{
+   Evas_Object *subobj = va_arg(*list, Evas_Object *);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
+
+   if (evas_object_box_remove(wd->resize_obj, subobj))
      elm_widget_sub_object_del(obj, subobj);
 }
 
 EAPI void
 elm_box_unpack_all(Evas_Object *obj)
+{
+   ELM_BOX_CHECK(obj);
+   eo_do(obj, elm_obj_box_unpack_all());
+}
+
+static void
+_unpack_all(Eo *obj, void *_pd EINA_UNUSED, va_list *list EINA_UNUSED)
 {
    Evas_Object_Box_Data *bd;
    Evas_Object_Box_Option *opt;
    Eina_List *l;
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
-
-   bd = evas_object_smart_data_get(ELM_WIDGET_DATA(sd)->resize_obj);
+   bd = evas_object_smart_data_get(wd->resize_obj);
    EINA_LIST_FOREACH (bd->children, l, opt)
      elm_widget_sub_object_del(obj, opt->obj);
 
    /* EINA_FALSE means to delete objects as well */
-   evas_object_box_remove_all(ELM_WIDGET_DATA(sd)->resize_obj, EINA_FALSE);
+   evas_object_box_remove_all(wd->resize_obj, EINA_FALSE);
 }
 
 EAPI void
@@ -588,14 +683,22 @@ elm_box_layout_set(Evas_Object *obj,
                    Ecore_Cb free_data)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_layout_set(cb, data, free_data));
+}
 
+static void
+_layout_set(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
+{
+   Evas_Object_Box_Layout cb = va_arg(*list, Evas_Object_Box_Layout);
+   const void *data = va_arg(*list, const void *);
+   Ecore_Cb free_data = va_arg(*list, Ecore_Cb);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
    if (cb)
      evas_object_box_layout_set
-       (ELM_WIDGET_DATA(sd)->resize_obj, cb, data, free_data);
+       (wd->resize_obj, cb, data, free_data);
    else
      evas_object_box_layout_set
-       (ELM_WIDGET_DATA(sd)->resize_obj, _elm_box_custom_layout, obj, NULL);
+       (wd->resize_obj, _elm_box_custom_layout, obj, NULL);
 }
 
 EAPI void
@@ -676,7 +779,7 @@ elm_box_transition_free(void *data)
      box_data->start.free_data(box_data->start.data);
    if ((box_data->end.free_data) && (box_data->end.data))
      box_data->end.free_data(box_data->end.data);
-   EINA_LIST_FREE (box_data->objs, tad)
+   EINA_LIST_FREE(box_data->objs, tad)
      free(tad);
 
    evas_object_event_callback_del
@@ -685,11 +788,7 @@ elm_box_transition_free(void *data)
      (box_data->box, SIG_CHILD_ADDED, _transition_layout_child_added);
    evas_object_smart_callback_del
      (box_data->box, SIG_CHILD_REMOVED, _transition_layout_child_removed);
-   if (box_data->animator)
-     {
-        ecore_animator_del(box_data->animator);
-        box_data->animator = NULL;
-     }
+   if (box_data->animator) ecore_animator_del(box_data->animator);
 
    free(data);
 }
@@ -698,9 +797,17 @@ EAPI Eina_List *
 elm_box_children_get(const Evas_Object *obj)
 {
    ELM_BOX_CHECK(obj) NULL;
-   ELM_BOX_DATA_GET(obj, sd);
+   Eina_List *ret = NULL;
+   eo_do((Eo *) obj, elm_obj_box_children_get(&ret));
+   return ret;
+}
 
-   return evas_object_box_children_get(ELM_WIDGET_DATA(sd)->resize_obj);
+static void
+_children_get(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
+{
+   Eina_List **ret = va_arg(*list, Eina_List **);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
+   *ret = evas_object_box_children_get(wd->resize_obj);
 }
 
 EAPI void
@@ -709,10 +816,18 @@ elm_box_padding_set(Evas_Object *obj,
                     Evas_Coord vertical)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_padding_set(horizontal, vertical));
+}
+
+static void
+_padding_set(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
+{
+   Evas_Coord horizontal = va_arg(*list, Evas_Coord);
+   Evas_Coord vertical = va_arg(*list, Evas_Coord);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    evas_object_box_padding_set
-     (ELM_WIDGET_DATA(sd)->resize_obj, horizontal, vertical);
+     (wd->resize_obj, horizontal, vertical);
 }
 
 EAPI void
@@ -721,10 +836,17 @@ elm_box_padding_get(const Evas_Object *obj,
                     Evas_Coord *vertical)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do((Eo *) obj, elm_obj_box_padding_get(horizontal, vertical));
+}
 
+static void
+_padding_get(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
+{
+   Evas_Coord *horizontal = va_arg(*list, Evas_Coord *);
+   Evas_Coord *vertical = va_arg(*list, Evas_Coord *);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
    evas_object_box_padding_get
-     (ELM_WIDGET_DATA(sd)->resize_obj, horizontal, vertical);
+     (wd->resize_obj, horizontal, vertical);
 }
 
 EAPI void
@@ -733,10 +855,18 @@ elm_box_align_set(Evas_Object *obj,
                   double vertical)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_align_set(horizontal, vertical));
+}
+
+static void
+_align_set(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
+{
+   double horizontal = va_arg(*list, double);
+   double vertical = va_arg(*list, double);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    evas_object_size_hint_align_set
-     (ELM_WIDGET_DATA(sd)->resize_obj, horizontal, vertical);
+     (wd->resize_obj, horizontal, vertical);
 }
 
 EAPI void
@@ -745,23 +875,114 @@ elm_box_align_get(const Evas_Object *obj,
                   double *vertical)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do((Eo *) obj, elm_obj_box_align_get(horizontal, vertical));
+}
+
+static void
+_align_get(Eo *obj, void *_pd EINA_UNUSED, va_list *list)
+{
+   double *horizontal = va_arg(*list, double *);
+   double *vertical = va_arg(*list, double *);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    evas_object_size_hint_align_get
-     (ELM_WIDGET_DATA(sd)->resize_obj, horizontal, vertical);
+     (wd->resize_obj, horizontal, vertical);
 }
 
 EAPI void
 elm_box_recalculate(Evas_Object *obj)
 {
    ELM_BOX_CHECK(obj);
-   ELM_BOX_DATA_GET(obj, sd);
+   eo_do(obj, elm_obj_box_recalculate());
+}
+
+static void
+_recalculate(Eo *obj, void *_pd, va_list *list EINA_UNUSED)
+{
+   Elm_Box_Smart_Data *sd = _pd;
 
    if (sd->recalc) return;
 
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
    evas_object_smart_need_recalculate_set
-     (ELM_WIDGET_DATA(sd)->resize_obj, EINA_TRUE);
+     (wd->resize_obj, EINA_TRUE);
    sd->recalc++;
-   evas_object_smart_calculate(ELM_WIDGET_DATA(sd)->resize_obj);
+   evas_object_smart_calculate(wd->resize_obj);
    sd->recalc--;
 }
+
+static void
+_class_constructor(Eo_Class *klass)
+{
+   const Eo_Op_Func_Description func_desc[] = {
+        EO_OP_FUNC(EO_BASE_ID(EO_BASE_SUB_ID_CONSTRUCTOR), _constructor),
+
+        EO_OP_FUNC(EVAS_OBJ_SMART_ID(EVAS_OBJ_SMART_SUB_ID_ADD), _elm_box_smart_add),
+        EO_OP_FUNC(EVAS_OBJ_SMART_ID(EVAS_OBJ_SMART_SUB_ID_DEL), _elm_box_smart_del),
+
+        EO_OP_FUNC(ELM_WIDGET_ID(ELM_WIDGET_SUB_ID_SUB_OBJECT_DEL), _elm_box_smart_sub_object_del),
+        EO_OP_FUNC(ELM_WIDGET_ID(ELM_WIDGET_SUB_ID_THEME), _elm_box_smart_theme),
+        EO_OP_FUNC(ELM_WIDGET_ID(ELM_WIDGET_SUB_ID_FOCUS_NEXT_MANAGER_IS),  _elm_box_smart_focus_next_manager_is),
+        EO_OP_FUNC(ELM_WIDGET_ID(ELM_WIDGET_SUB_ID_FOCUS_NEXT),  _elm_box_smart_focus_next),
+        EO_OP_FUNC(ELM_WIDGET_ID(ELM_WIDGET_SUB_ID_FOCUS_DIRECTION_MANAGER_IS), _elm_box_smart_focus_direction_manager_is),
+        EO_OP_FUNC(ELM_WIDGET_ID(ELM_WIDGET_SUB_ID_FOCUS_DIRECTION), _elm_box_smart_focus_direction),
+
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_HORIZONTAL_SET), _horizontal_set),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_HORIZONTAL_GET), _horizontal_get),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_HOMOGENEOUS_SET), _homogeneous_set),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_HOMOGENEOUS_GET), _homogeneous_get),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_PACK_START), _pack_start),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_PACK_END), _pack_end),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_PACK_BEFORE), _pack_before),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_PACK_AFTER), _pack_after),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_CLEAR), _clear),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_UNPACK), _unpack),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_UNPACK_ALL), _unpack_all),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_LAYOUT_SET), _layout_set),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_CHILDREN_GET), _children_get),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_PADDING_SET), _padding_set),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_PADDING_GET), _padding_get),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_ALIGN_SET), _align_set),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_ALIGN_GET), _align_get),
+        EO_OP_FUNC(ELM_OBJ_BOX_ID(ELM_OBJ_BOX_SUB_ID_RECALCULATE), _recalculate),
+        EO_OP_FUNC_SENTINEL
+   };
+   eo_class_funcs_set(klass, func_desc);
+
+   evas_smart_legacy_type_register(MY_CLASS_NAME_LEGACY, klass);
+}
+
+static const Eo_Op_Description op_desc[] = {
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_HORIZONTAL_SET, "Set the horizontal orientation."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_HORIZONTAL_GET, "Get the horizontal orientation."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_HOMOGENEOUS_SET, "Set the box to arrange its children homogeneously."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_HOMOGENEOUS_GET, "Get whether the box is using homogeneous mode or not."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_PACK_START, "Add an object to the beginning of the pack list."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_PACK_END, "Add an object at the end of the pack list."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_PACK_BEFORE, "Adds an object to the box before the indicated object."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_PACK_AFTER, "Adds an object to the box after the indicated object."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_CLEAR, "Clear the box of all children."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_UNPACK, "Unpack a box item."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_UNPACK_ALL, "Remove all items from the box, without deleting them."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_LAYOUT_SET, "Set the layout defining function to be used by the box."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_CHILDREN_GET, "Retrieve a list of the objects packed into the box."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_PADDING_SET, "Set the space (padding) between the box's elements."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_PADDING_GET, "Get the space (padding) between the box's elements."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_ALIGN_SET, "Set the alignment of the whole bounding box of contents."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_ALIGN_GET, "Get the alignment of the whole bounding box of contents."),
+     EO_OP_DESCRIPTION(ELM_OBJ_BOX_SUB_ID_RECALCULATE, "Force the box to recalculate its children packing."),
+     EO_OP_DESCRIPTION_SENTINEL
+};
+
+static const Eo_Class_Description class_desc = {
+     EO_VERSION,
+     MY_CLASS_NAME,
+     EO_CLASS_TYPE_REGULAR,
+     EO_CLASS_DESCRIPTION_OPS(&ELM_OBJ_BOX_BASE_ID, op_desc, ELM_OBJ_BOX_SUB_ID_LAST),
+     NULL,
+     sizeof(Elm_Box_Smart_Data),
+     _class_constructor,
+     NULL
+};
+
+EO_DEFINE_CLASS(elm_obj_box_class_get, &class_desc, ELM_OBJ_WIDGET_CLASS, NULL);
