@@ -2,9 +2,7 @@
 # include "elementary_config.h"
 #endif
 
-#ifdef HAVE_FORK
 #include <dlfcn.h> /* dlopen,dlclose,etc */
-#endif
 
 #ifdef HAVE_CRT_EXTERNS_H
 # include <crt_externs.h>
@@ -14,15 +12,19 @@
 # include <Evil.h>
 #endif
 
-#ifdef HAVE_EMOTION
-# include <Emotion.h>
-#endif
+#include <Emotion.h>
 
 #include <Elementary.h>
 #include "elm_priv.h"
 
 #define SEMI_BROKEN_QUICKLAUNCH 1
 
+#ifdef __CYGWIN__
+# define LIBEXT ".dll"
+#else
+# define LIBEXT ".so"
+#endif
+
 static Elm_Version _version = { VMAJ, VMIN, VMIC, VREV };
 EAPI Elm_Version *elm_version = &_version;
 
@@ -36,19 +38,19 @@ _elm_dangerous_call_check(const char *call)
    eval = getenv("ELM_NO_FINGER_WAGGLING");
    if ((eval) && (!strcmp(eval, buf)))
      return 0;
-   printf("ELEMENTARY FINGER WAGGLE!!!!!!!!!!\n"
-          "\n"
-          "  %s() used.\n"
-          "PLEASE see the API documentation for this function. This call\n"
-          "should almost never be used. Only in very special cases.\n"
-          "\n"
-          "To remove this warning please set the environment variable:\n"
-          "  ELM_NO_FINGER_WAGGLING\n"
-          "To the value of the Elementary version + revision number. e.g.:\n"
-          "  1.2.5.40295\n"
-          "\n"
-          ,
-          call);
+   ERR("ELEMENTARY FINGER WAGGLE!!!!!!!!!!\n"
+       "\n"
+       "  %s() used.\n"
+       "PLEASE see the API documentation for this function. This call\n"
+       "should almost never be used. Only in very special cases.\n"
+       "\n"
+       "To remove this warning please set the environment variable:\n"
+       "  ELM_NO_FINGER_WAGGLING\n"
+       "To the value of the Elementary version + revision number. e.g.:\n"
+       "  1.2.5.40295\n"
+       "\n"
+       ,
+       call);
    return 1;
 }
 
@@ -95,10 +97,8 @@ _elm_emotion_init(void)
 {
    if (_emotion_inited) return ;
 
-#if HAVE_EMOTION
    emotion_init();
    _emotion_inited = EINA_TRUE;
-#endif
 }
 
 void
@@ -106,13 +106,13 @@ _elm_emotion_shutdown(void)
 {
    if (!_emotion_inited) return ;
 
-#if HAVE_EMOTION
    emotion_shutdown();
    _emotion_inited = EINA_FALSE;
-#endif
 }
 
 static void *app_mainfunc = NULL;
+static const char *app_name = NULL;
+static const char *app_desktop_entry = NULL;
 static const char *app_domain = NULL;
 static const char *app_checkfile = NULL;
 
@@ -128,6 +128,8 @@ static const char *app_locale_dir = NULL;
 
 static Eina_Prefix *app_pfx = NULL;
 
+static Ecore_Event_Handler *system_handlers[2] = { NULL, NULL };
+
 static void
 _prefix_check(void)
 {
@@ -147,7 +149,7 @@ _prefix_check(void)
    dirs[1] = app_compile_lib_dir;
    dirs[2] = app_compile_data_dir;
    dirs[3] = app_compile_locale_dir;
-   
+
    if (!dirs[0]) dirs[0] = "/usr/local/bin";
    if (!dirs[1]) dirs[1] = "/usr/local/lib";
    if (!dirs[2])
@@ -159,7 +161,7 @@ _prefix_check(void)
 
    if (app_domain)
      {
-        caps = alloca(strlen(app_domain) + 1);
+        caps = alloca(eina_stringshare_strlen(app_domain) + 1);
         for (p1 = (char *)app_domain, p2 = caps; *p1; p1++, p2++)
            *p2 = toupper(*p1);
         *p2 = 0;
@@ -178,11 +180,6 @@ _prefix_shutdown(void)
    if (app_compile_lib_dir) eina_stringshare_del(app_compile_lib_dir);
    if (app_compile_data_dir) eina_stringshare_del(app_compile_data_dir);
    if (app_compile_locale_dir) eina_stringshare_del(app_compile_locale_dir);
-   if (app_prefix_dir) eina_stringshare_del(app_prefix_dir);
-   if (app_bin_dir) eina_stringshare_del(app_bin_dir);
-   if (app_lib_dir) eina_stringshare_del(app_lib_dir);
-   if (app_data_dir) eina_stringshare_del(app_data_dir);
-   if (app_locale_dir) eina_stringshare_del(app_locale_dir);
    app_mainfunc = NULL;
    app_domain = NULL;
    app_checkfile = NULL;
@@ -198,14 +195,127 @@ _prefix_shutdown(void)
    app_pfx = NULL;
 }
 
+static struct {
+     Eina_Module *handle;
+     void (*init)(void);
+     void (*shutdown)(void);
+     Eina_Bool (*app_connect)(const char *appname);
+     Eina_Bool is_init;
+} _clouseau_info;
+
+#define _CLOUSEAU_LOAD_SYMBOL(cls_struct, sym) \
+   do \
+     { \
+        (cls_struct).sym = eina_module_symbol_get((cls_struct).handle, "clouseau_" #sym); \
+        if (!(cls_struct).sym) \
+          { \
+             WRN("Failed loading symbol '%s' from the clouseau library.", "clouseau_" #sym); \
+             eina_module_free((cls_struct).handle); \
+             (cls_struct).handle = NULL; \
+             return EINA_FALSE; \
+          } \
+     } \
+   while (0)
+
+static void
+_elm_clouseau_unload()
+{
+   if (!_clouseau_info.is_init)
+      return;
+
+   if (_clouseau_info.shutdown)
+     {
+        _clouseau_info.shutdown();
+     }
+
+   if (_clouseau_info.handle)
+     {
+        eina_module_free(_clouseau_info.handle);
+        _clouseau_info.handle = NULL;
+     }
+
+   _clouseau_info.is_init = EINA_FALSE;
+}
+
+Eina_Bool
+_elm_clouseau_reload()
+{
+   if (!_elm_config->clouseau_enable)
+     {
+        _elm_clouseau_unload();
+        return EINA_TRUE;
+     }
+
+   if (_clouseau_info.is_init)
+      return EINA_TRUE;
+
+   _clouseau_info.handle = eina_module_new(
+         PACKAGE_LIB_DIR "/libclouseau" LIBEXT);
+   if (!eina_module_load(_clouseau_info.handle))
+     {
+        WRN("Failed loading the clouseau library.");
+        eina_module_free(_clouseau_info.handle);
+        _clouseau_info.handle = NULL;
+        return EINA_FALSE;
+     }
+
+   _CLOUSEAU_LOAD_SYMBOL(_clouseau_info, init);
+   _CLOUSEAU_LOAD_SYMBOL(_clouseau_info, shutdown);
+   _CLOUSEAU_LOAD_SYMBOL(_clouseau_info, app_connect);
+
+   _clouseau_info.init();
+   if(!_clouseau_info.app_connect(elm_app_name_get()))
+     {
+        ERR("Failed connecting to the clouseau server.");
+     }
+
+   _clouseau_info.is_init = EINA_TRUE;
+
+   return EINA_TRUE;
+}
+
+Eina_Bool _sys_memory_changed(void *data EINA_UNUSED, int type EINA_UNUSED, void *event EINA_UNUSED)
+{
+   Ecore_Memory_State state = ecore_memory_state_get();
+
+   if (state != ECORE_MEMORY_STATE_LOW)
+     return ECORE_CALLBACK_PASS_ON;
+
+   elm_cache_all_flush();
+   return ECORE_CALLBACK_PASS_ON;
+}
+
+Eina_Bool _sys_lang_changed(void *data EINA_UNUSED, int type EINA_UNUSED, void *event EINA_UNUSED)
+{
+   char *lang;
+
+   lang = getenv("LANG");
+   if (!lang)
+     lang = getenv("LC_MESSAGES");
+   if (!lang)
+     lang = getenv("LC_ALL");
+
+   if (lang)
+     elm_language_set(lang);
+   else
+     ERR("Language not set in environment");
+
+   return ECORE_CALLBACK_PASS_ON;
+}
+
 EAPI int
 elm_init(int    argc,
          char **argv)
 {
-   elm_quicklaunch_init(argc, argv);
+   _elm_init_count++;
    if (_elm_init_count > 1) return _elm_init_count;
+   elm_quicklaunch_init(argc, argv);
    elm_quicklaunch_sub_init(argc, argv);
    _prefix_shutdown();
+
+   system_handlers[0] = ecore_event_handler_add(ECORE_EVENT_MEMORY_STATE, _sys_memory_changed, NULL);
+   system_handlers[1] = ecore_event_handler_add(ECORE_EVENT_LOCALE_CHANGED, _sys_lang_changed, NULL);
+
    return _elm_init_count;
 }
 
@@ -219,10 +329,21 @@ elm_shutdown(void)
      }
    _elm_init_count--;
    if (_elm_init_count > 0) return _elm_init_count;
+
+   if (system_handlers[0])
+     ecore_event_handler_del(system_handlers[0]);
+   if (system_handlers[1])
+     ecore_event_handler_del(system_handlers[1]);
+
    _elm_win_shutdown();
    while (_elm_win_deferred_free) ecore_main_loop_iterate();
+
+   _elm_clouseau_unload();
 // wrningz :(
 //   _prefix_shutdown();
+   ELM_SAFE_FREE(app_name, eina_stringshare_del);
+   ELM_SAFE_FREE(app_desktop_entry, eina_stringshare_del);
+
    elm_quicklaunch_sub_shutdown();
    elm_quicklaunch_shutdown();
    return _elm_init_count;
@@ -236,6 +357,18 @@ elm_app_info_set(void *mainfunc, const char *dom, const char *checkfile)
    eina_stringshare_replace(&app_checkfile, checkfile);
 }
 
+EAPI void
+elm_app_name_set(const char *name)
+{
+   eina_stringshare_replace(&app_name, name);
+}
+
+EAPI void
+elm_app_desktop_entry_set(const char *path)
+{
+   eina_stringshare_replace(&app_desktop_entry, path);
+}
+
 EAPI void
 elm_app_compile_bin_dir_set(const char *dir)
 {
@@ -260,6 +393,22 @@ elm_app_compile_locale_set(const char *dir)
    eina_stringshare_replace(&app_compile_locale_dir, dir);
 }
 
+EAPI const char *
+elm_app_name_get(void)
+{
+   if (app_name) return app_name;
+
+   return "";
+}
+
+EAPI const char *
+elm_app_desktop_entry_get(void)
+{
+   if (app_desktop_entry) return app_desktop_entry;
+
+   return "";
+}
+
 EAPI const char *
 elm_app_prefix_dir_get(void)
 {
@@ -310,15 +459,71 @@ elm_app_locale_dir_get(void)
    return app_locale_dir;
 }
 
-#ifdef ELM_EDBUS
-static int _elm_need_e_dbus = 0;
-#endif
+static Eina_Bool _elm_need_e_dbus = EINA_FALSE;
+static void *e_dbus_handle = NULL;
+
 EAPI Eina_Bool
 elm_need_e_dbus(void)
 {
-#ifdef ELM_EDBUS
-   if (_elm_need_e_dbus++) return EINA_TRUE;
-   e_dbus_init();
+   int (*init_func)(void) = NULL;
+
+   if (_elm_need_e_dbus) return EINA_TRUE;
+   /* We use RTLD_NOLOAD when available, so we are sure to use the 'libeldbus' that was linked to the binary */
+#ifndef RTLD_NOLOAD
+# define RTLD_NOLOAD RTLD_GLOBAL
+#endif
+   if (!e_dbus_handle) e_dbus_handle = dlopen("libeldbus.so", RTLD_LAZY | RTLD_NOLOAD);
+   if (!e_dbus_handle) return EINA_FALSE;
+   init_func = dlsym(e_dbus_handle, "e_dbus_init");
+   if (!init_func) return EINA_FALSE;
+   _elm_need_e_dbus = EINA_TRUE;
+   init_func();
+   return EINA_TRUE;
+}
+
+static void
+_elm_unneed_e_dbus(void)
+{
+   int (*shutdown_func)(void) = NULL;
+
+   if (!_elm_need_e_dbus) return;
+   shutdown_func = dlsym(e_dbus_handle, "e_dbus_shutdown");
+   if (!shutdown_func) return;
+   _elm_need_e_dbus = EINA_FALSE;
+   shutdown_func();
+
+   dlclose(e_dbus_handle);
+   e_dbus_handle = NULL;
+}
+
+static Eina_Bool _elm_need_eldbus = EINA_FALSE;
+EAPI Eina_Bool
+elm_need_eldbus(void)
+{
+   if (_elm_need_eldbus) return EINA_TRUE;
+   _elm_need_eldbus = EINA_TRUE;
+   eldbus_init();
+   return EINA_TRUE;
+}
+
+static void
+_elm_unneed_eldbus(void)
+{
+   if (!_elm_need_eldbus) return;
+   _elm_need_eldbus = EINA_FALSE;
+   eldbus_shutdown();
+}
+
+#ifdef ELM_ELOCATION
+static Eina_Bool _elm_need_elocation = EINA_FALSE;
+#endif
+EAPI Eina_Bool
+elm_need_elocation(void)
+{
+#ifdef ELM_ELOCATION
+   if (_elm_need_elocation) return EINA_TRUE;
+   _elm_need_elocation = EINA_TRUE;
+   elocation_init();
    return EINA_TRUE;
 #else
    return EINA_FALSE;
@@ -326,24 +531,22 @@ elm_need_e_dbus(void)
 }
 
 static void
-_elm_unneed_e_dbus(void)
+_elm_unneed_elocation(void)
 {
-#ifdef ELM_EDBUS
-   if (--_elm_need_e_dbus) return;
-
-   _elm_need_e_dbus = 0;
-   e_dbus_shutdown();
+#ifdef ELM_ELOCATION
+   if (!_elm_need_elocation) return;
+   _elm_need_elocation = EINA_FALSE;
+   eldbus_shutdown();
 #endif
 }
 
-#ifdef ELM_EFREET
-static int _elm_need_efreet = 0;
-#endif
+static Eina_Bool _elm_need_efreet = EINA_FALSE;
+
 EAPI Eina_Bool
 elm_need_efreet(void)
 {
-#ifdef ELM_EFREET
-   if (_elm_need_efreet++) return EINA_TRUE;
+   if (_elm_need_efreet) return EINA_TRUE;
+   _elm_need_efreet = EINA_TRUE;
    efreet_init();
    efreet_mime_init();
    efreet_trash_init();
@@ -362,22 +565,16 @@ elm_need_efreet(void)
      }
    */
    return EINA_TRUE;
-#else
-   return EINA_FALSE;
-#endif
 }
 
 static void
 _elm_unneed_efreet(void)
 {
-#ifdef ELM_EFREET
-   if (--_elm_need_efreet) return;
-
-   _elm_need_efreet = 0;
+   if (!_elm_need_efreet) return;
+   _elm_need_efreet = EINA_FALSE;
    efreet_trash_shutdown();
    efreet_mime_shutdown();
    efreet_shutdown();
-#endif
 }
 
 EAPI void
@@ -396,9 +593,7 @@ EAPI int
 elm_quicklaunch_init(int    argc,
                      char **argv)
 {
-   _elm_init_count++;
    _elm_ql_init_count++;
-   if (_elm_init_count > 1) return _elm_ql_init_count;
    if (_elm_ql_init_count > 1) return _elm_ql_init_count;
    eina_init();
    _elm_log_dom = eina_log_domain_register("elementary", EINA_COLOR_LIGHTBLUE);
@@ -423,8 +618,12 @@ elm_quicklaunch_init(int    argc,
    ecore_file_init();
 
    _elm_exit_handler = ecore_event_handler_add(ECORE_EVENT_SIGNAL_EXIT, _elm_signal_exit, NULL);
-   
-   if (argv) _elm_appname = strdup(ecore_file_file_get(argv[0]));
+
+   if (argv)
+     {
+        _elm_appname = strdup(ecore_file_file_get(argv[0]));
+        elm_app_name_set(_elm_appname);
+     }
 
    pfx = eina_prefix_new(argv ? argv[0] : NULL, elm_quicklaunch_init,
                          "ELM", "elementary", "config/profile.cfg",
@@ -440,6 +639,12 @@ elm_quicklaunch_init(int    argc,
    if (!_elm_data_dir) _elm_data_dir = eina_stringshare_add("/");
    if (!_elm_lib_dir) _elm_lib_dir = eina_stringshare_add("/");
 
+   eina_log_timing(_elm_log_dom,
+                   EINA_LOG_STATE_STOP,
+                   EINA_LOG_STATE_INIT);
+
+   if (quicklaunch_on)
+     _elm_init_count++;
    return _elm_ql_init_count;
 }
 
@@ -456,7 +661,7 @@ elm_quicklaunch_sub_init(int    argc,
         return _elm_sub_init_count;
 #endif
      }
-   
+
    if (!quicklaunch_on)
      {
         ecore_app_args_set(argc, (const char **)argv);
@@ -466,13 +671,10 @@ elm_quicklaunch_sub_init(int    argc,
         _elm_config_init();
         _elm_config_sub_init();
         ecore_evas_init(); // FIXME: check errors
-#ifdef HAVE_ELEMENTARY_ECORE_IMF
         ecore_imf_init();
-#endif
-#ifdef HAVE_ELEMENTARY_ECORE_CON
         ecore_con_init();
         ecore_con_url_init();
-#endif
+        _elm_prefs_init();
         _elm_ews_wm_init();
      }
    return _elm_sub_init_count;
@@ -493,14 +695,11 @@ elm_quicklaunch_sub_shutdown(void)
      {
         _elm_win_shutdown();
         _elm_module_shutdown();
+        _elm_prefs_shutdown();
         _elm_ews_wm_shutdown();
-#ifdef HAVE_ELEMENTARY_ECORE_CON
         ecore_con_url_shutdown();
         ecore_con_shutdown();
-#endif
-#ifdef HAVE_ELEMENTARY_ECORE_IMF
         ecore_imf_shutdown();
-#endif
         ecore_evas_shutdown();
         _elm_config_sub_shutdown();
 #define ENGINE_COMPARE(name) (!strcmp(_elm_config->engine, name))
@@ -528,24 +727,28 @@ elm_quicklaunch_shutdown(void)
 {
    _elm_ql_init_count--;
    if (_elm_ql_init_count > 0) return _elm_ql_init_count;
+
+   eina_log_timing(_elm_log_dom,
+                   EINA_LOG_STATE_STOP,
+                   EINA_LOG_STATE_SHUTDOWN);
+
    if (pfx) eina_prefix_free(pfx);
    pfx = NULL;
-   eina_stringshare_del(_elm_data_dir);
-   _elm_data_dir = NULL;
-   eina_stringshare_del(_elm_lib_dir);
-   _elm_lib_dir = NULL;
-
-   free(_elm_appname);
-   _elm_appname = NULL;
+   ELM_SAFE_FREE(_elm_data_dir, eina_stringshare_del);
+   ELM_SAFE_FREE(_elm_lib_dir, eina_stringshare_del);
+   ELM_SAFE_FREE(_elm_appname, free);
 
    _elm_config_shutdown();
 
-   ecore_event_handler_del(_elm_exit_handler);
-   _elm_exit_handler = NULL;
+   ELM_SAFE_FREE(_elm_exit_handler, ecore_event_handler_del);
 
    _elm_theme_shutdown();
+   _elm_unneed_systray();
+   _elm_unneed_sys_notify();
    _elm_unneed_efreet();
    _elm_unneed_e_dbus();
+   _elm_unneed_eldbus();
+   _elm_unneed_elocation();
    _elm_unneed_ethumb();
    _elm_unneed_web();
    ecore_file_shutdown();
@@ -553,9 +756,7 @@ elm_quicklaunch_shutdown(void)
 #ifdef HAVE_ELEMENTARY_EMAP
    emap_shutdown();
 #endif
-#ifdef HAVE_EMOTION
    _elm_emotion_shutdown();
-#endif
 
    ecore_shutdown();
    eet_shutdown();
@@ -566,8 +767,6 @@ elm_quicklaunch_shutdown(void)
         _elm_log_dom = -1;
      }
 
-   _elm_widget_type_clear();
-
    eina_shutdown();
    return _elm_ql_init_count;
 }
@@ -614,67 +813,92 @@ static int (*qr_main)(int    argc,
 
 EAPI Eina_Bool
 elm_quicklaunch_prepare(int    argc,
-                        char **argv)
+                        char **argv,
+                        const char *cwd)
 {
 #ifdef HAVE_FORK
-   char *exe;
+   char *exe, *exe2, *p;
+   char *exename;
 
    if (argc <= 0 || argv == NULL) return EINA_FALSE;
 
-   exe = elm_quicklaunch_exe_path_get(argv[0]);
+   exe = elm_quicklaunch_exe_path_get(argv[0], cwd);
    if (!exe)
      {
         ERR("requested quicklaunch binary '%s' does not exist\n", argv[0]);
         return EINA_FALSE;
      }
-   else
-     {
-        char *exe2, *p;
-        char *exename;
 
-        exe2 = malloc(strlen(exe) + 1 + 10);
-        strcpy(exe2, exe);
-        p = strrchr(exe2, '/');
-        if (p) p++;
-        else p = exe2;
-        exename = alloca(strlen(p) + 1);
-        strcpy(exename, p);
-        *p = 0;
-        strcat(p, "../lib/");
-        strcat(p, exename);
-        strcat(p, ".so");
-        if (!access(exe2, R_OK | X_OK))
-          {
-             free(exe);
-             exe = exe2;
-          }
-        else
-          free(exe2);
+   exe2 = malloc(strlen(exe) + 1 + 7 + strlen(LIBEXT));
+   strcpy(exe2, exe);
+   p = strrchr(exe2, '/');
+   if (p) p++;
+   else p = exe2;
+   exename = alloca(strlen(p) + 1);
+   strcpy(exename, p);
+   *p = 0;
+   strcat(p, "../lib/");
+   strcat(p, exename);
+   strcat(p, LIBEXT);
+   if (access(exe2, R_OK | X_OK) != 0)
+     {
+        free(exe2);
+        exe2 = NULL;
      }
+
+   /* Try linking to executable first. Works with PIE files. */
    qr_handle = dlopen(exe, RTLD_NOW | RTLD_GLOBAL);
-   if (!qr_handle)
+   if (qr_handle)
      {
-        fprintf(stderr, "dlerr: %s\n", dlerror());
-        WRN("dlopen('%s') failed: %s", exe, dlerror());
-        free(exe);
-        return EINA_FALSE;
-     }
-   INF("dlopen('%s') = %p", exe, qr_handle);
-   qr_main = dlsym(qr_handle, "elm_main");
-   INF("dlsym(%p, 'elm_main') = %p", qr_handle, qr_main);
-   if (!qr_main)
-     {
-        WRN("not quicklauncher capable: no elm_main in '%s'", exe);
+        INF("dlopen('%s') = %p", exe, qr_handle);
+        qr_main = dlsym(qr_handle, "elm_main");
+        if (qr_main)
+          {
+             INF("dlsym(%p, 'elm_main') = %p", qr_handle, qr_main);
+             free(exe2);
+             free(exe);
+             return EINA_TRUE;
+          }
         dlclose(qr_handle);
         qr_handle = NULL;
+     }
+
+   if (!exe2)
+     {
+        WRN("not quicklauncher capable: '%s'", exe);
         free(exe);
         return EINA_FALSE;
      }
    free(exe);
+
+   /* Open companion .so file.
+    * Support for legacy quicklaunch apps with separate library.
+    */
+   qr_handle = dlopen(exe2, RTLD_NOW | RTLD_GLOBAL);
+   if (!qr_handle)
+     {
+        fprintf(stderr, "dlerr: %s\n", dlerror());
+        WRN("dlopen('%s') failed: %s", exe2, dlerror());
+        free(exe2);
+        return EINA_FALSE;
+     }
+   INF("dlopen('%s') = %p", exe2, qr_handle);
+   qr_main = dlsym(qr_handle, "elm_main");
+   INF("dlsym(%p, 'elm_main') = %p", qr_handle, qr_main);
+   if (!qr_main)
+     {
+        WRN("not quicklauncher capable: no elm_main in '%s'", exe2);
+        dlclose(qr_handle);
+        qr_handle = NULL;
+        free(exe2);
+        return EINA_FALSE;
+     }
+   free(exe2);
    return EINA_TRUE;
 #else
-   return EINA_FALSE;
+   (void)argc;
    (void)argv;
+   return EINA_FALSE;
 #endif
 }
 
@@ -721,6 +945,7 @@ elm_quicklaunch_fork(int    argc,
    if (postfork_func) postfork_func(postfork_data);
 
    ecore_fork_reset();
+   eina_main_loop_define();
 
    if (quicklaunch_on)
      {
@@ -728,7 +953,7 @@ elm_quicklaunch_fork(int    argc,
         _elm_appname = NULL;
         if ((argv) && (argv[0]))
           _elm_appname = strdup(ecore_file_file_get(argv[0]));
-        
+
 #ifdef SEMI_BROKEN_QUICKLAUNCH
         ecore_app_args_set(argc, (const char **)argv);
         evas_init();
@@ -747,9 +972,7 @@ elm_quicklaunch_fork(int    argc,
 # endif
           }
         ecore_evas_init(); // FIXME: check errors
-# ifdef HAVE_ELEMENTARY_ECORE_IMF
         ecore_imf_init();
-# endif
 #endif
      }
 
@@ -787,16 +1010,17 @@ elm_quicklaunch_fallback(int    argc,
                          char **argv)
 {
    int ret;
+   char cwd[PATH_MAX];
    elm_quicklaunch_init(argc, argv);
    elm_quicklaunch_sub_init(argc, argv);
-   elm_quicklaunch_prepare(argc, argv);
+   elm_quicklaunch_prepare(argc, argv, getcwd(cwd, sizeof(cwd)));
    ret = qr_main(argc, argv);
    exit(ret);
    return ret;
 }
 
 EAPI char *
-elm_quicklaunch_exe_path_get(const char *exe)
+elm_quicklaunch_exe_path_get(const char *exe, const char *cwd)
 {
    static char *path = NULL;
    static Eina_List *pathlist = NULL;
@@ -804,8 +1028,13 @@ elm_quicklaunch_exe_path_get(const char *exe)
    const Eina_List *l;
    char buf[PATH_MAX];
    if (exe[0] == '/') return strdup(exe);
-   if ((exe[0] == '.') && (exe[1] == '/')) return strdup(exe);
-   if ((exe[0] == '.') && (exe[1] == '.') && (exe[2] == '/')) return strdup(exe);
+   if (cwd)
+     pathlist = eina_list_append(pathlist, eina_stringshare_add(cwd));
+   else
+     {
+        if ((exe[0] == '.') && (exe[1] == '/')) return strdup(exe);
+        if ((exe[0] == '.') && (exe[1] == '.') && (exe[2] == '/')) return strdup(exe);
+     }
    if (!path)
      {
         const char *p, *pp;
@@ -853,6 +1082,15 @@ EAPI void
 elm_exit(void)
 {
    ecore_main_loop_quit();
+
+   if (elm_policy_get(ELM_POLICY_EXIT) == ELM_POLICY_EXIT_WINDOWS_DEL)
+     {
+        Eina_List *l, *l_next;
+        Evas_Object *win;
+
+        EINA_LIST_FOREACH_SAFE(_elm_win_list, l, l_next, win)
+          evas_object_del(win);
+     }
 }
 
 //FIXME: Use Elm_Policy Parameter when 2.0 is released.
@@ -949,28 +1187,47 @@ EAPI void
 elm_object_part_text_set(Evas_Object *obj, const char *part, const char *label)
 {
    EINA_SAFETY_ON_NULL_RETURN(obj);
-   elm_widget_text_part_set(obj, part, label);
+   elm_widget_part_text_set(obj, part, label);
 }
 
 EAPI const char *
 elm_object_part_text_get(const Evas_Object *obj, const char *part)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(obj, NULL);
-   return elm_widget_text_part_get(obj, part);
+   return elm_widget_part_text_get(obj, part);
 }
 
 EAPI void
-elm_object_domain_translatable_text_part_set(Evas_Object *obj, const char *part, const char *domain, const char *text)
+elm_object_domain_translatable_part_text_set(Evas_Object *obj, const char *part, const char *domain, const char *text)
 {
    EINA_SAFETY_ON_NULL_RETURN(obj);
-   elm_widget_domain_translatable_text_part_set(obj, part, domain, text);
+   elm_widget_domain_translatable_part_text_set(obj, part, domain, text);
 }
 
 EAPI const char *
-elm_object_translatable_text_part_get(const Evas_Object *obj, const char *part)
+elm_object_translatable_part_text_get(const Evas_Object *obj, const char *part)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(obj, NULL);
-   return elm_widget_translatable_text_part_get(obj, part);
+   return elm_widget_translatable_part_text_get(obj, part);
+}
+
+EAPI void
+elm_object_domain_part_text_translatable_set(Evas_Object *obj, const char *part, const char *domain, Eina_Bool translatable)
+{
+   EINA_SAFETY_ON_NULL_RETURN(obj);
+   elm_widget_domain_part_text_translatable_set(obj, part, domain, translatable);
+}
+
+EINA_DEPRECATED EAPI void
+elm_object_domain_translatable_text_part_set(Evas_Object *obj, const char *part, const char *domain, const char *text)
+{
+   elm_object_domain_translatable_part_text_set(obj, part, domain, text);
+}
+
+EINA_DEPRECATED EAPI const char *
+elm_object_translatable_text_part_get(const Evas_Object *obj, const char *part)
+{
+   return elm_object_translatable_part_text_get(obj, part);
 }
 
 EAPI void
@@ -1058,15 +1315,15 @@ elm_object_focus_set(Evas_Object *obj,
    if (elm_widget_is(obj))
      {
         const char *type;
-        
+
         if (focus == elm_widget_focus_get(obj)) return;
-        
+
         // ugly, but, special case for inlined windows
         type = evas_object_type_get(obj);
         if ((type) && (!strcmp(type, "elm_win")))
           {
              Evas_Object *inlined = elm_win_inlined_image_object_get(obj);
-             
+
              if (inlined)
                {
                   evas_object_focus_set(inlined, focus);
@@ -1156,6 +1413,30 @@ elm_object_focus_next(Evas_Object        *obj,
    elm_widget_focus_cycle(obj, dir);
 }
 
+EAPI Evas_Object *
+elm_object_focus_next_object_get(const Evas_Object  *obj,
+                                 Elm_Focus_Direction dir)
+{
+   EINA_SAFETY_ON_NULL_RETURN_VAL(obj, NULL);
+   return elm_widget_focus_next_object_get(obj, dir);
+}
+
+EAPI void
+elm_object_focus_next_object_set(Evas_Object        *obj,
+                                 Evas_Object        *next,
+                                 Elm_Focus_Direction dir)
+{
+   EINA_SAFETY_ON_NULL_RETURN(obj);
+   elm_widget_focus_next_object_set(obj, next, dir);
+}
+
+EAPI Evas_Object *
+elm_object_focused_object_get(const Evas_Object *obj)
+{
+   EINA_SAFETY_ON_NULL_RETURN_VAL(obj, NULL);
+   return elm_widget_focused_object_get(obj);
+}
+
 EAPI void
 elm_object_tree_focus_allow_set(Evas_Object *obj,
                                 Eina_Bool    tree_focusable)
@@ -1318,8 +1599,8 @@ elm_object_tree_dump(const Evas_Object *top)
 #ifdef ELM_DEBUG
    elm_widget_tree_dump(top);
 #else
-   return;
    (void)top;
+   return;
 #endif
 }
 
@@ -1332,9 +1613,9 @@ elm_object_tree_dot_dump(const Evas_Object *top,
    elm_widget_tree_dot_dump(top, f);
    fclose(f);
 #else
-   return;
    (void)top;
    (void)file;
+   return;
 #endif
 }
 
@@ -1391,6 +1672,24 @@ elm_object_item_part_text_get(const Elm_Object_Item *it, const char *part)
    return _elm_widget_item_part_text_get((Elm_Widget_Item *)it, part);
 }
 
+EAPI void
+elm_object_item_domain_translatable_part_text_set(Elm_Object_Item *it, const char *part, const char *domain, const char *text)
+{
+   _elm_widget_item_domain_translatable_part_text_set((Elm_Widget_Item *)it, part, domain, text);
+}
+
+EAPI const char *
+elm_object_item_translatable_part_text_get(const Elm_Object_Item *it, const char *part)
+{
+   return _elm_widget_item_translatable_part_text_get((Elm_Widget_Item *)it, part);
+}
+
+EAPI void
+elm_object_item_domain_part_text_translatable_set(Elm_Object_Item *it, const char *part, const char *domain, Eina_Bool translatable)
+{
+   _elm_widget_item_domain_part_text_translatable_set((Elm_Widget_Item *)it, part, domain, translatable);
+}
+
 EAPI void
 elm_object_access_info_set(Evas_Object *obj, const char *txt)
 {
@@ -1403,12 +1702,69 @@ elm_object_name_find(const Evas_Object *obj, const char *name, int recurse)
    return elm_widget_name_find(obj, name, recurse);
 }
 
+EAPI void
+elm_object_orientation_mode_disabled_set(Evas_Object *obj, Eina_Bool disabled)
+{
+   elm_widget_orientation_mode_disabled_set(obj, disabled);
+}
+
+EAPI Eina_Bool
+elm_object_orientation_mode_disabled_get(const Evas_Object *obj)
+{
+   return elm_widget_orientation_mode_disabled_get(obj);
+}
+
 EAPI void
 elm_object_item_access_info_set(Elm_Object_Item *it, const char *txt)
 {
    _elm_widget_item_access_info_set((Elm_Widget_Item *)it, txt);
 }
 
+EAPI Evas_Object *
+elm_object_item_access_register(Elm_Object_Item *item)
+{
+   Elm_Widget_Item *it;
+
+   it = (Elm_Widget_Item *)item;
+
+   _elm_access_widget_item_register(it);
+
+   if (it) return it->access_obj;
+   return NULL;
+}
+
+EAPI void
+elm_object_item_access_unregister(Elm_Object_Item *item)
+{
+   _elm_access_widget_item_unregister((Elm_Widget_Item *)item);
+}
+
+EAPI Evas_Object *
+elm_object_item_access_object_get(const Elm_Object_Item *item)
+{
+   if (!item) return NULL;
+
+   return ((Elm_Widget_Item *)item)->access_obj;
+}
+
+EAPI void
+elm_object_item_access_order_set(Elm_Object_Item *item, Eina_List *objs)
+{
+   _elm_access_widget_item_access_order_set((Elm_Widget_Item *)item, objs);
+}
+
+EAPI const Eina_List *
+elm_object_item_access_order_get(const Elm_Object_Item *item)
+{
+   return _elm_access_widget_item_access_order_get((Elm_Widget_Item *)item);
+}
+
+EAPI void
+elm_object_item_access_order_unset(Elm_Object_Item *item)
+{
+   _elm_access_widget_item_access_order_unset((Elm_Widget_Item *)item);
+}
+
 EAPI void *
 elm_object_item_data_get(const Elm_Object_Item *it)
 {
@@ -1427,6 +1783,18 @@ elm_object_item_signal_emit(Elm_Object_Item *it, const char *emission, const cha
    _elm_widget_item_signal_emit((Elm_Widget_Item *)it, emission, source);
 }
 
+EAPI void
+elm_object_item_signal_callback_add(Elm_Object_Item *it, const char *emission, const char *source, Elm_Object_Item_Signal_Cb func, void *data)
+{
+   _elm_widget_item_signal_callback_add((Elm_Widget_Item *)it, emission, source, (Elm_Widget_Item_Signal_Cb) func, data);
+}
+
+EAPI void *
+elm_object_item_signal_callback_del(Elm_Object_Item *it, const char *emission, const char *source, Elm_Object_Item_Signal_Cb func)
+{
+   return _elm_widget_item_signal_callback_del((Elm_Widget_Item *)it, emission, source, (Elm_Widget_Item_Signal_Cb) func);
+}
+
 EAPI void elm_object_item_disabled_set(Elm_Object_Item *it, Eina_Bool disabled)
 {
    _elm_widget_item_disabled_set((Elm_Widget_Item *)it, disabled);
@@ -1530,3 +1898,22 @@ elm_object_item_cursor_engine_only_get(const Elm_Object_Item *it)
 {
    return elm_widget_item_cursor_engine_only_get(it);
 }
+
+EAPI Evas_Object *
+elm_object_item_track(Elm_Object_Item *it)
+{
+   return elm_widget_item_track((Elm_Widget_Item *)it);
+}
+
+void
+elm_object_item_untrack(Elm_Object_Item *it)
+{
+   elm_widget_item_untrack((Elm_Widget_Item *)it);
+}
+
+int
+elm_object_item_track_get(const Elm_Object_Item *it)
+{
+   return elm_widget_item_track_get((Elm_Widget_Item *)it);
+}
+
