@@ -1,5 +1,10 @@
+#ifdef HAVE_CONFIG_H
+# include "elementary_config.h"
+#endif
+
 #include <Elementary.h>
 #include <Elementary_Cursor.h>
+
 #include "elm_priv.h"
 
 #ifdef HAVE_ELEMENTARY_X
@@ -148,14 +153,14 @@ struct _Elm_Cursor
 
    Eina_Bool visible:1;
    Eina_Bool use_engine:1;
-   Eina_Bool engine_only:1;
+   Eina_Bool theme_search:1;
 };
 
 static void
 _elm_cursor_obj_del(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
 {
    Elm_Cursor *cur = data;
-   
+
    if (cur)
      {
         evas_object_event_callback_del_full(cur->obj, EVAS_CALLBACK_DEL,
@@ -175,7 +180,7 @@ _elm_cursor_obj_add(Evas_Object *obj, Elm_Cursor *cur)
      return EINA_FALSE;
 
    if (!_elm_theme_object_set(obj, cur->obj, "cursor", cur->cursor_name,
-                              cur->style ? cur->style : "default"))
+                             cur->style ? cur->style : "default"))
      {
         evas_object_del(cur->obj);
         cur->obj = NULL;
@@ -212,7 +217,7 @@ _elm_cursor_mouse_in(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSE
    if (cur->visible) return;
    evas_event_freeze(cur->evas);
    cur->visible = EINA_TRUE;
-   if ((!cur->engine_only) && (!cur->use_engine))
+   if (!cur->use_engine)
      {
         if (!cur->obj)
           _elm_cursor_obj_add(cur->eventarea, cur);
@@ -261,7 +266,7 @@ _elm_cursor_mouse_out(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUS
         return;
      }
 
-   if ((!cur->engine_only) || (!cur->use_engine))
+   if (!cur->use_engine)
      ecore_evas_object_cursor_set(cur->ee, NULL, ELM_OBJECT_LAYER_CURSOR,
                                   cur->hot_x, cur->hot_y);
    else
@@ -297,7 +302,7 @@ _elm_cursor_strcmp(const void *data1, const void *data2)
 static void
 _elm_cursor_cur_set(Elm_Cursor *cur)
 {
-   if (cur->engine_only)
+   if (!cur->theme_search)
      {
         INF("Using only engine cursors");
         cur->use_engine = EINA_TRUE;
@@ -383,7 +388,7 @@ elm_object_sub_cursor_set(Evas_Object *eventarea, Evas_Object *owner, const char
 
    cur->owner = owner;
    cur->eventarea = eventarea;
-   cur->engine_only = _elm_config->cursor_engine_only;
+   cur->theme_search = !_elm_config->cursor_engine_only;
    cur->visible = EINA_FALSE;
 
    cur->cursor_name = eina_stringshare_add(cursor);
@@ -512,7 +517,7 @@ EAPI void
 elm_object_cursor_theme_search_enabled_set(Evas_Object *obj, Eina_Bool theme_search)
 {
    ELM_CURSOR_GET_OR_RETURN(cur, obj);
-   cur->engine_only = theme_search;
+   cur->theme_search = theme_search;
    if (cur->obj)
      {
         evas_object_del(cur->obj);
@@ -526,5 +531,5 @@ EAPI Eina_Bool
 elm_object_cursor_theme_search_enabled_get(const Evas_Object *obj)
 {
    ELM_CURSOR_GET_OR_RETURN(cur, obj, EINA_FALSE);
-   return cur->engine_only;
+   return cur->theme_search;
 }
