@@ -1,14 +1,18 @@
+#ifdef HAVE_CONFIG_H
+# include "elementary_config.h"
+#endif
+
 #include <Elementary.h>
 
 // module api funcs needed
 EAPI int
-elm_modapi_init(void *m)
+elm_modapi_init(void *m __UNUSED__)
 {
    return 1; // succeed always
 }
 
 EAPI int
-elm_modapi_shutdown(void *m)
+elm_modapi_shutdown(void *m __UNUSED__)
 {
    return 1; // succeed always
 }
